<?php

namespace App\Http\Controllers\Admin;

use App\Enums\TempUploadFileStatus;
use App\Events\FileUploadProgress;
use App\Events\ImportProgressUpdated;
use App\Helper;
use App\Http\Controllers\Controller;
use App\Jobs\ProcessExcelImport;
use App\Models\DataFactory;
use App\Models\TempUploadFile;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Bus;
use Illuminate\Support\Str;
use Inertia\Inertia;

class DataFactoryController extends Controller
{
    /**
     * @throws \Throwable
     */
    public function index(): \Inertia\Response
    {

        return Inertia::render("Admin/DataFactory/List", [
            'data' => DataFactory::latest()->when(\request('q'), function ($q) {
                $q->where('first_name', "LIKE", "%" . \request('q') . "%");
            })->paginate(50),
        ]);
    }

    public function startDispatch(): JsonResponse
    {
        $batch = Bus::batch([])->name("FIle Processing")->dispatch();
        $tempFiles = TempUploadFile::where(['user_id' => Auth::id(), 'status' => TempUploadFileStatus::PENDING->value])->get();
        foreach ($tempFiles as $item) {
            $batch->add(new ProcessExcelImport($item->path, $item->original_name));
        }
        return response()->json([
            'message' => "Data inserting job successfully run",
            'batch'   => $batch->toArray()
        ]);
    }

    public function store(Request $request): JsonResponse
    {
        $request->validate([
            'file' => 'required|file',
        ]);

        $file = $request->file('file');
        $userId = auth()->id();
        $fileIndex = $request->input('index');
        // Simulate processing with progress updates
        $totalSize = $file->getSize();
        $uploaded = 0;
        $stream = fopen($file->getRealPath(), 'r');

        while (!feof($stream)) {
            $chunk = fread($stream, 1024 * 1024); // 1MB chunks
            $uploaded += strlen($chunk);
            $percent = min(100, round(($uploaded / $totalSize) * 100));
            // Broadcast progress
            FileUploadProgress::dispatch($userId, $fileIndex, $percent, null);
            //usleep(100000); // Simulate chunk processing time
        }

        fclose($stream);
        //$path = $file->store('imports');
        $file = $request->file('file');
        $filename = time() . '_' . $file->getClientOriginalName();
        $file->move(public_path('imports'), $filename);
        $path = public_path('imports')."/$filename";
        TempUploadFile::create([
            'user_id'       => Auth::id(),
            'filename'      => Str::beforeLast($path, "/"),
            'original_name' => $file->getClientOriginalName(),
            'path'          => $path,
            'status'        => TempUploadFileStatus::PENDING->value,
        ]);
        FileUploadProgress::dispatch($userId, $fileIndex, 100, $path);
        return response()->json(['path' => $path]);
    }

    public function startUploading(Request $request)
    {
        dd($request->all());
    }

    public function processImport(Request $request)
    {
        try {
            $request->validate([
                'file' => 'required|file|mimes:xlsx,xls,csv|max:512000'
            ]);

            $file = $request->file('file');
            $path = $file->store('imports');
            $batch = Bus::batch([
                new ProcessExcelImport($path)
            ])->name('importExcel')->dispatch();

            return response()->json([
                'message' => 'Import started successfully. We will process your file in the background.',
                'batchId' => $batch->id
            ]);
        } catch (\Exception $exception) {
            dd($exception->getMessage());
        } catch (\Throwable $e) {
            dd($e->getMessage());
        }
    }
}
