<?php

namespace App\Http\Controllers\Admin;

use App\Enums\SubscriptionStatus;
use App\Http\Controllers\Controller;
use App\Http\Requests\Admin\SubscriptionIndexRequest;
use App\Http\Resources\Admin\SubscriptionResource;
use App\Models\Plan;
use App\Models\Subscription;
use App\Models\User;
use Illuminate\Http\JsonResponse;
use Inertia\Inertia;

class SubscriptionController extends Controller
{
    public function index(SubscriptionIndexRequest $request)
    {
        return Inertia::render("Admin/Subscription/List", [
            'subscriptions' => Subscription::getItemList($request),
            'plans'         => Plan::latest()->get()->map(fn($plan) => [
                'label' => $plan->name,
                'value' => $plan->id,
            ])->unshift([
                'label' => "All",
                'value' => ""
            ]),
            'users'         => User::latest()->get()->map(fn($plan) => [
                'label' => $plan->name,
                'value' => $plan->id,
            ])->unshift([
                'label' => "All",
                'value' => ""
            ]),
            'statuses'      => SubscriptionStatus::cases(),
            'counts'        => [
                'total'       => Subscription::count(),
                'pending'     => Subscription::where('migration_status', SubscriptionStatus::PENDING->value)->count(),
                'processing'  => Subscription::where('migration_status', SubscriptionStatus::PROCESSING->value)->count(),
                'completed'   => Subscription::where('migration_status', SubscriptionStatus::COMPLETED->value)->count(),
                'failed'      => Subscription::where('migration_status', SubscriptionStatus::FAILED->value)->count(),
                'rolled_back' => Subscription::where('migration_status', SubscriptionStatus::ROLLED_BACK->value)->count(),
            ]
        ]);
    }

    public function show(Subscription $subscription): JsonResponse
    {
        $subscription->load(['user', 'plan', 'migratedFromPlan']);

        return response()->json([
            'data'    => new SubscriptionResource($subscription),
            'history' => $subscription->history
        ]);
    }
}
