<?php

namespace App\Http\Controllers;

use App\Models\Plan;
use Inertia\Inertia;
use Illuminate\Http\Request;
use App\Http\Resources\PlanResource;
use App\Http\Requests\PlanIndexRequest;
use Inertia\Response;

class PlanController extends Controller
{

    public array $headers = [
        'name'                        => true,
        'price'                       => true,
        'currency'                    => true,
        'billing_cycle_days'          => true,
        'billing_cycle_type'          => false,
        'product_line'                => true,
        'is_active'                   => false,
        'active_subscriptions_count'  => false,
        'expired_subscriptions_count' => false,
    ];


    public function index(PlanIndexRequest $request): Response
    {
        $plans = Plan::getItemLest($request);
        return Inertia::render('Admin/Plan/List', [
            'plans' => $plans
        ]);
    }

    public function show(Plan $plan): \Illuminate\Http\JsonResponse
    {
        $plan->load([
            'subscriptions' => fn($q) => $q->latest()->limit(10),
            'subscriptions.user'
        ]);

        return response()->json([
            'data'    => new PlanResource($plan),
            'metrics' => [
                'total_revenue'     => $plan->subscriptions()->sum('amount_paid'),
                'monthly_recurring' => $plan->subscriptions()->active()->sum('price'),
                'churn_rate'        => $plan->churn_rate,
            ]
        ]);
    }
}
