<?php

namespace App\Jobs;

use Illuminate\Bus\Batchable;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Facades\Bus;
use Illuminate\Support\Facades\Storage;
use PhpOffice\PhpSpreadsheet\IOFactory;

class ImportExcelItemsProcess implements ShouldQueue
{
    use Batchable, Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

    public function __construct(
        public string $filePath,
        public string $originalFileName
    )
    {
    }




    public function handle(): void
    {
        $rows = $this->getExcelRows();
        $chunks = array_chunk($rows, 5000);
        Bus::batch(collect($chunks)->map(fn ($chunk) => new ProcessExcelImportOnly($chunk)))->name('Excel Import')->dispatch();
        Storage::delete($this->filePath);
    }
}
