<?php

namespace App\Jobs;

use App\Enums\TempUploadFileStatus;
use App\Events\ImportProgressUpdated;
use App\Helper;
use App\Models\TempUploadFile;
use Illuminate\Bus\Batchable;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Storage;

class ProcessExcelImport implements ShouldQueue
{
    use Batchable, Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

    public function __construct(public string $filePath, public string $originalFileName)
    {
    }


    public function handle(): void
    {
        if ($this->batch()->cancelled()) {
            return;
        }
        try {
            //dd($this->filePath);
            //DB::connection()->getPdo()->setAttribute(\PDO::ATTR_EMULATE_PREPARES, true);
            $rows = Helper::getExcelRows($this->filePath);
            $chunks = array_chunk($rows, 1000);
            foreach ($chunks as $index => $chunk) {
                $progress = (($index + 1) / count($chunks)) * 100;
                ProcessExcelImportOnly::dispatch($chunk);
                ImportProgressUpdated::dispatch($this->batchId, round($progress), 'processing');
            }

            ImportProgressUpdated::dispatch($this->batchId, 100, 'completed');
            /*$tem = TempUploadFile::where('path', $this->filePath)->first()->update([
                'status' => TempUploadFileStatus::COMPLETED->value
            ]);
            Log::info("Temp Update", $tem);*/
            $filePath = public_path('imports/' . $this->originalFileName);
            if (File::exists($filePath)) {
                File::delete($filePath);
            }
        } catch (\Exception $exception) {
            $this->failWithLogging($exception);
            dd($exception->getMessage(), "FAILED");
        } catch (\Throwable $e) {
            dd($e->getMessage());
        }
    }


    public function failWithLogging(\Throwable $e): void
    {
        Log::error("Excel import failed", [
            'file'  => $this->originalFileName,
            'error' => $e->getMessage(),
            'trace' => $e->getTraceAsString()
        ]);

        $this->fail($e);
    }


}
