<?php

namespace App\Jobs;

use App\Helper;
use App\Models\DataFactory;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;

class ProcessExcelImportOnly implements ShouldQueue
{
    use Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

    public function __construct(private readonly array $items)
    {
    }


    public function handle(): void
    {
        try {
            $insertToData = [];
            foreach ($this->items as $row) {
                if (Helper::isValidRow($row)) {
                    $insertToData[] = Helper::transformRow($row);
                }
            }
            DataFactory::insert($insertToData);
        } catch (\Exception $exception) {
            Log::error('Import failed: ' . $exception->getMessage());
            $this->fail($exception);
        }
    }

}
