<?php

namespace App\Models;

use App\Scopes\SearchScope;
use Database\Factories\DataFactoryFactory;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Collection;

class DataFactory extends Model
{
    /** @use HasFactory<DataFactoryFactory> */
    use HasFactory, SearchScope;

    protected $fillable = ['cell_number', 'business_name', 'first_name', 'last_name', 'email', 'website', 'city', 'state', 'business_address', 'pin_code'];


    public static function getCities($cities = []): Collection
    {
        return collect($cities)->map(function ($item) {
            return [
                'key'   => ltrim(current($item)),
                'value' => trim((string)end($item)),
            ];
        })->groupBy("key");
    }

    public static function getStates($states = []): Collection
    {
        return collect($states)->map(function ($item) {
            $values = array_values($item); // re-index the array
            $key = $values[0] ?? null;
            $value = $values[1] ?? null;
            return [
                'key'   => $key,
                'value' => preg_replace('/^\s+|\s+$/u', '', (string)$value),
            ];
        })->groupBy("key");
    }


    public static function applyFilter(array $request)
    {
        $phraseCities = static::getCities($request['cities'] ?? []);
        $phraseStates = static::getStates($request['states'] ?? []);
        return static::query()->when($phraseCities->has("exact"), function ($query) use ($phraseCities) {
            foreach ($phraseCities->get("exact")->pluck('value') as $item) {
                $query->orWhere('city', "LIKE", "%$item%");
            }
        })->when($phraseCities->has("exclude"), function ($query) use ($phraseCities) {
            foreach ($phraseCities->get("exclude")->pluck('value') as $item) {
                $query->orWhere('city', "LIKE", "%$item%");
            }
        })->when($phraseStates->has("exact"), function ($query) use ($phraseStates) {
            foreach ($phraseStates->get("exact")->pluck('value') as $item) {
                $query->orWhere("state", "LIKE", "%$item%");
            }
        })->when($phraseStates->has("exclude"), function ($query) use ($phraseStates) {
            foreach ($phraseStates->get("exclude")->pluck('value') as $item) {
                $query->orWhere('state', "NOT LIKE", "%$item%");
            }
        })->when($request['search'] ?? '', function ($query, $search) {
            $query->search($search);
        });
    }

}
