<?php

namespace App\Notifications;

use App\Models\Subscription;
use Illuminate\Bus\Queueable;
use Illuminate\Notifications\Notification;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;

class MigrationFailed extends Notification implements ShouldQueue
{
    use Queueable;

    public function __construct(
        public Subscription $subscription,
        public \Throwable   $exception
    )
    {
    }

    public function via($notifiable): array
    {
        return ['mail', 'database'];
    }

    public function toMail($notifiable): MailMessage
    {
        return (new MailMessage)
            ->subject('Subscription Migration Failed')
            ->line('We encountered an error processing your subscription change:')
            ->line($this->exception->getMessage())
            ->action('Contact Support', url('/support'))
            ->line('Please try again or contact our support team.');
    }

    public function toArray($notifiable): array
    {
        return [
            'subscription_id' => $this->subscription->id,
            'error'           => $this->exception->getMessage(),
            'timestamp'       => now()->toDateTimeString()
        ];
    }
}
