<?php

namespace App\Notifications;

use App\Models\Subscription;
use Illuminate\Bus\Queueable;
use Illuminate\Notifications\Notification;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;

class SubscriptionMigrated extends Notification implements ShouldQueue
{
    use Queueable;

    public function __construct(public Subscription $subscription)
    {
    }

    public function via($notifiable): array
    {
        return ['mail', 'database'];
    }

    public function toMail($notifiable): MailMessage
    {
        return (new MailMessage)->subject('Subscription Plan Changed')
            ->line('Your subscription has been successfully migrated.')
            ->line('New Plan: ' . $this->subscription->plan->name)
            ->action('View Dashboard', url('/dashboard'))
            ->line('Thank you for using our service!');
    }

    public function toArray($notifiable): array
    {
        return [
            'subscription_id' => $this->subscription->id,
            'new_plan'        => $this->subscription->plan->name,
            'effective_date'  => now()->toDateTimeString()
        ];
    }
}
