<?php

namespace App\Providers;

use App\Models\Subscription;
use App\Models\User;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Support\Facades\Cache;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\ServiceProvider;
use Illuminate\Support\Str;
use Laravel\Cashier\Cashier;
use Stripe\SubscriptionItem;

/**
 * @method toBase()
 */
class AppServiceProvider extends ServiceProvider
{
    /**
     * Register any application services.
     */
    public function register(): void
    {

    }

    /**
     * Bootstrap any application services.
     */

    public function boot(): void
    {
        Cashier::useCustomerModel(User::class);
        Cashier::calculateTaxes();
        Cashier::useSubscriptionModel(Subscription::class);
        Cashier::useSubscriptionItemModel(SubscriptionItem::class);
        Builder::macro('fastCount', function () {
            $query = $this->toBase();
            $connection = $query->getConnection();
            $bindings = $query->getBindings();

            if (config('database.default') === 'pgsql') {
                $sql = "SELECT COUNT(*) FROM ({$query->toSql()}) as sub";
                return (int)$connection->selectOne($sql, $bindings)->count;
            }

            // MySQL/MariaDB implementation
            $countQuery = clone $query;
            $countQuery->selectRaw('SQL_CALC_FOUND_ROWS 1')->limit(1);
            $sql = $countQuery->toSql();
            $connection->select($sql, $countQuery->getBindings());
            return (int)$connection->selectOne('SELECT FOUND_ROWS() as aggregate')->aggregate;
        });

        // Add cache layer for frequent queries
        Builder::macro('cachedCount', function ($ttl = 300) {
            $query = $this->toBase();
            $cacheKey = 'count:'.md5($query->toSql().serialize($query->getBindings()));

            return Cache::remember($cacheKey, $ttl, function () use ($query) {
                return $query->fastCount();
            });
        });
    }
}
