<?php

namespace App\Scopes;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Scope;
use Illuminate\Support\Str;

trait SearchScope
{
    public static array $synonyms = [
        // General Synonyms
        'travel'     => ['tour', 'journey', 'trip', 'voyage', 'excursion', 'trek', 'expedition', 'roam', 'cruise'],
        'records'    => ['data', 'entries', 'logs', 'documents', 'files', 'archives', 'reports', 'registers'],
        'fast'       => ['quick', 'rapid', 'swift', 'speedy', 'hasty', 'brisk', 'fleet', 'expeditious'],
        'buy'        => ['purchase', 'acquire', 'obtain', 'procure', 'shop', 'secure', 'invest', 'grab'],
        'help'       => ['assist', 'aid', 'support', 'guide', 'facilitate', 'serve', 'relieve', 'rescue'],
        'error'      => ['mistake', 'bug', 'fault', 'issue', 'glitch', 'defect', 'flaw', 'oversight'],
        'create'     => ['build', 'design', 'develop', 'generate', 'produce', 'craft', 'invent', 'establish'],
        'delete'     => ['remove', 'erase', 'eliminate', 'discard', 'expunge', 'purge', 'obliterate'],
        'improve'    => ['enhance', 'optimize', 'refine', 'upgrade', 'boost', 'amend', 'polish'],
        'find'       => ['locate', 'discover', 'detect', 'uncover', 'identify', 'retrieve', 'trace'],

        // Business/Company Terms
        'company'    => ['business', 'firm', 'enterprise', 'organization', 'corporation', 'venture', 'startup'],
        'service'    => ['offering', 'solution', 'assistance', 'support', 'amenity', 'provision', 'utility'],
        'product'    => ['item', 'goods', 'merchandise', 'commodity', 'article', 'offering', 'line'],
        'client'     => ['customer', 'consumer', 'user', 'patron', 'buyer', 'purchaser', 'subscriber'],
        'invoice'    => ['bill', 'statement', 'receipt', 'tab', 'charge', 'account', 'voucher', 'tabulation'],
        'profit'     => ['revenue', 'earnings', 'gain', 'income', 'proceeds', 'margin', 'surplus'],
        'employee'   => ['staff', 'worker', 'personnel', 'associate', 'team member', 'laborer'],

        // Technology Terms
        'software'   => ['application', 'program', 'app', 'platform', 'tool', 'system', 'suite', 'script'],
        'data'       => ['information', 'records', 'details', 'stats', 'metrics', 'facts', 'figures'],
        'server'     => ['host', 'node', 'system', 'cloud', 'backend', 'mainframe', 'datacenter'],
        'code'       => ['script', 'program', 'algorithm', 'logic', 'instructions', 'syntax', 'commands'],
        'network'    => ['system', 'web', 'grid', 'infrastructure', 'connection', 'framework', 'mesh'],
        'database'   => ['repository', 'datastore', 'archive', 'warehouse', 'bank', 'collection'],
        'security'   => ['protection', 'safety', 'encryption', 'firewall', 'safeguard', 'defense'],

        // Location-Based Terms
        'city'       => ['town', 'metropolis', 'municipality', 'urban area', 'borough', 'district', 'capital'],
        'address'    => ['location', 'place', 'site', 'residence', 'destination', 'venue', 'premises'],
        'state'      => ['province', 'region', 'territory', 'district', 'zone', 'jurisdiction', 'county'],
        'country'    => ['nation', 'land', 'realm', 'kingdom', 'territory', 'state', 'commonwealth'],
        'area'       => ['zone', 'region', 'sector', 'district', 'vicinity', 'locale', 'neighborhood'],
        'map'        => ['chart', 'plan', 'layout', 'diagram', 'guide', 'atlas', 'blueprint'],

        // Email/Communication Terms
        'email'      => ['message', 'communication', 'memo', 'note', 'letter', 'dispatch', 'correspondence'],
        'contact'    => ['reach out', 'connect', 'communicate', 'get in touch', 'notify', 'ping', 'message'],
        'send'       => ['dispatch', 'transmit', 'deliver', 'forward', 'share', 'issue', 'circulate'],
        'reply'      => ['respond', 'answer', 'acknowledge', 'react', 'retort', 'counter', 'reciprocate'],
        'attachment' => ['file', 'document', 'add-on', 'enclosure', 'inclusion', 'appendix', 'supplement'],

        // Emotions & Actions
        'happy'      => ['joyful', 'cheerful', 'delighted', 'pleased', 'ecstatic', 'content', 'thrilled'],
        'angry'      => ['furious', 'enraged', 'irritated', 'livid', 'incensed', 'provoked', 'fuming'],
        'sad'        => ['unhappy', 'sorrowful', 'dejected', 'gloomy', 'melancholy', 'despondent'],
        'run'        => ['sprint', 'jog', 'dash', 'race', 'hurry', 'rush', 'scurry', 'bolt'],
        'talk'       => ['speak', 'converse', 'chat', 'discuss', 'communicate', 'negotiate', 'confer'],

        // Time-Related Terms
        'now'        => ['immediately', 'instantly', 'promptly', 'straightaway', 'directly', 'urgently'],
        'later'      => ['afterward', 'subsequently', 'eventually', 'next', 'thereafter', 'someday'],
        'soon'       => ['shortly', 'momentarily', 'quickly', 'promptly', 'imminently', 'before long'],
        'delay'      => ['postpone', 'defer', 'suspend', 'stall', 'procrastinate', 'adjourn'],
        'deadline'   => ['due date', 'cutoff', 'limit', 'target', 'timeframe', 'schedule'],


        'school'     => [
            'academy', 'institution', 'educational institution', 'college',
            'university', 'learning center', 'campus', 'schoolhouse'
        ],
        'student'    => [
            'learner', 'pupil', 'scholar', 'undergraduate', 'trainee',
            'apprentice', 'cadet', 'disciple'
        ],
        'teacher'    => [
            'educator', 'instructor', 'professor', 'tutor', 'lecturer',
            'mentor', 'coach', 'faculty', 'guide'
        ],
        'class'      => [
            'course', 'lesson', 'subject', 'module', 'workshop',
            'seminar', 'curriculum', 'program'
        ],
        'homework'   => [
            'assignment', 'project', 'task', 'exercise', 'study',
            'practice', 'preparation', 'coursework'
        ],
        'exam'       => [
            'test', 'assessment', 'quiz', 'evaluation', 'examination',
            'final', 'midterm', 'oral exam'
        ],
        'principal'  => [
            'headmaster', 'headmistress', 'dean', 'director',
            'administrator', 'superintendent', 'chancellor'
        ],
        'grade'      => [
            'mark', 'score', 'rating', 'result', 'assessment',
            'evaluation', 'ranking'
        ],
        'library'    => [
            'resource center', 'study hall', 'archive', 'reading room',
            'book repository', 'media center'
        ],
        'textbook'   => [
            'manual', 'guidebook', 'workbook', 'coursebook',
            'reference book', 'primer', 'compendium'
        ],
        'graduation' => [
            'commencement', 'convocation', 'completion',
            'certification', 'culmination', 'award ceremony'
        ],
        'classroom'  => ['lecture hall', 'learning space', 'lab', 'studio', 'workshop'],
        'tuition'    => ['fees', 'payment', 'charges', 'cost', 'expense'],
        'syllabus'   => ['curriculum', 'outline', 'schedule', 'plan', 'program'],
        'degree'     => ['qualification', 'certification', 'diploma', 'credential', 'title'],
        'research'   => ['study', 'investigation', 'analysis', 'exploration', 'inquiry'],
    ];

    protected function getSynonymsForTerm(string $term): array
    {
        return static::$synonyms[strtolower(trim($term))] ?? [];
    }


    protected function parseSearchQuery(string $query): array
    {
        // Extract excluded phrases (e.g., -"exact phrase")
        preg_match_all('/-\s*"([^"]+)"/', $query, $excludedPhraseMatches);
        $excluded_phrases = array_map('trim', $excludedPhraseMatches[1]);

        // Remove excluded phrases from the original query
        $query = preg_replace('/-\s*"([^"]+)"/', '', $query);

        // Extract included phrases (e.g., "exact phrase")
        preg_match_all('/"([^"]+)"/', $query, $includedPhraseMatches);
        $included_phrases = array_map('trim', $includedPhraseMatches[1]);

        // Remove included phrases from the original query
        $query = preg_replace('/"([^"]+)"/', '', $query);

        // Split remaining into terms and excluded terms (e.g., -term)
        $remaining = trim($query);
        $parts = preg_split('/\s+/', $remaining, -1, PREG_SPLIT_NO_EMPTY);

        $included_terms = [];
        $excluded_terms = [];

        foreach ($parts as $part) {
            $part = trim($part);
            if (str_starts_with($part, '-')) {
                $excluded_term = substr($part, 1);
                if (!empty($excluded_term)) {
                    $excluded_terms[] = $excluded_term;
                }
            } else {
                $included_terms[] = $part;
            }
        }

        return [
            'included_phrases' => $included_phrases,
            'included_terms'   => $included_terms,
            'excluded_phrases' => $excluded_phrases,
            'excluded_terms'   => $excluded_terms,
        ];
    }


    protected function escapeLike(string $value): string
    {
        return str_replace(['%', '_'], ['\%', '\_'], $value);
    }

    /*protected function getTermVariations(string $term): array
    {
        $variations = [
            $term,
            Str::singular($term),
            Str::plural($term)
        ];

        return array_unique(array_filter($variations));
    }*/

    protected function getTermVariations(string $term): array
    {
        $irregulars = [
            'mouse'  => ['mice'],
            'person' => ['people'],
            'foot'   => ['feet'],
            'tooth'  => ['teeth']
        ];

        $variations = [
            $term,
            Str::singular($term),
            Str::plural($term)
        ];

        if (array_key_exists($term, $irregulars)) {
            $variations = array_merge($variations, $irregulars[$term]);
        }

        return array_unique(array_filter($variations));
    }


    public function scopeSearch($query, $searchQuery = ""): void
    {
        $parsed = $this->parseSearchQuery($searchQuery);

        $included_phrases = $parsed['included_phrases'];
        $included_terms = $parsed['included_terms'];
        $excluded_phrases = $parsed['excluded_phrases'];
        $excluded_terms = $parsed['excluded_terms'];

        $fields = ['business_name', 'email'];

        // 1. Handle exact phrases (AND between phrases)
        foreach ($parsed['included_phrases'] as $phrase) {
            $phrase = $this->escapeLike($phrase);
            $query->where(function (Builder $q) use ($fields, $phrase) {
                foreach ($fields as $field) {
                    $q->orWhere($field, 'LIKE', "%{$phrase}%");
                }
            });
        }

        // 2. Handle individual terms (OR between terms)
        if (!empty($parsed['included_terms'])) {
            $query->where(function (Builder $q) use ($fields, $parsed) {
                foreach ($parsed['included_terms'] as $term) {
                    $q->orWhere(function (Builder $innerQ) use ($fields, $term) {
                        $termsToSearch = array_unique(array_merge(
                            $this->getTermVariations($term),
                            $this->getSynonymsForTerm($term)
                        ));

                        $innerQ->where(function (Builder $q2) use ($fields, $termsToSearch) {
                            foreach ($termsToSearch as $searchTerm) {
                                $searchTerm = $this->escapeLike($searchTerm);
                                $length = strlen($searchTerm);

                                // Determine patterns
                                $patterns = [];
                                if ($length <= 3) {
                                    $patterns[] = "{$searchTerm}%";
                                } else {
                                    $patterns[] = "%{$searchTerm}%";
                                    $patterns[] = substr($searchTerm, 0, 5) . '%';
                                }

                                // Add OR conditions for each pattern
                                $q2->orWhere(function (Builder $q3) use ($fields, $patterns) {
                                    foreach ($fields as $field) {
                                        foreach ($patterns as $pattern) {
                                            $q3->orWhere($field, 'LIKE', $pattern);
                                        }
                                    }
                                });
                            }
                        });
                    });
                }
            });
        }


        // 3. Handle exclusions (NOT conditions)
        foreach ($parsed['excluded_phrases'] as $phrase) {
            $phrase = $this->escapeLike($phrase);
            $query->where(function (Builder $q) use ($fields, $phrase) {
                foreach ($fields as $field) {
                    $q->whereNot($field, 'LIKE', "%{$phrase}%");
                }
            });
        }

        foreach ($parsed['excluded_terms'] as $term) {
            $term = $this->escapeLike($term);
            $query->where(function (Builder $q) use ($fields, $term) {
                foreach ($fields as $field) {
                    $q->whereNot($field, 'LIKE', "%{$term}%");
                }
            });
        }
    }

    /*public function scopeSearch($query, $searchQuery = "")
    {
        $parsed = $this->parseSearchQuery($searchQuery);

        $included_phrases = $parsed['included_phrases'];
        $included_terms = $parsed['included_terms'];
        $excluded_phrases = $parsed['excluded_phrases'];
        $excluded_terms = $parsed['excluded_terms'];

        $fields = ['business_name', 'email'];

        // 1. Handle exact phrases (AND logic)
        foreach ($included_phrases as $phrase) {
            $phrase = $this->escapeLike($phrase);
            $query->where(function (Builder $q) use ($fields, $phrase) {
                foreach ($fields as $field) {
                    $q->orWhere($field, 'LIKE', "%{$phrase}%");
                }
            });
        }

        // 2. Handle individual terms (OR logic between terms)
        if (!empty($included_terms)) {
            $query->where(function (Builder $q) use ($fields, $included_terms) {
                foreach ($included_terms as $term) {
                    $synonyms = $this->getSynonymsForTerm($term);
                    $searchTerms = array_unique(array_merge([$term], $synonyms));

                    $q->orWhere(function (Builder $innerQ) use ($fields, $searchTerms) {
                        foreach ($searchTerms as $searchTerm) {
                            $searchTerm = $this->escapeLike($searchTerm);
                            $length = strlen($searchTerm);

                            // Determine wildcard pattern
                            if ($length <= 3) {
                                $pattern = "{$searchTerm}%";
                            } else {
                                $pattern = "%{$searchTerm}%";
                            }

                            // Add stem pattern for longer terms
                            $stemPattern = null;
                            if ($length >= 5) {
                                $stem = substr($searchTerm, 0, 5);
                                $stemPattern = $this->escapeLike($stem) . '%';
                            }

                            $innerQ->where(function (Builder $q2) use ($fields, $pattern, $stemPattern) {
                                foreach ($fields as $field) {
                                    $q2->orWhere($field, 'LIKE', $pattern);
                                    if ($stemPattern) {
                                        $q2->orWhere($field, 'LIKE', $stemPattern);
                                    }
                                }
                            });
                        }
                    });
                }
            });
        }


        // 3. Handle exclusions (NOT logic)
        foreach ($excluded_phrases as $phrase) {
            $phrase = $this->escapeLike($phrase);
            $query->where(function (Builder $q) use ($fields, $phrase) {
                foreach ($fields as $field) {
                    $q->whereNot($field, 'LIKE', "%{$phrase}%");
                }
            });
        }


        foreach ($excluded_terms as $term) {
            $term = $this->escapeLike($term);
            $query->where(function (Builder $q) use ($fields, $term) {
                foreach ($fields as $field) {
                    $q->whereNot($field, 'LIKE', "%{$term}%");
                }
            });
        }
        return $query;
    }*/

    /*public function scopeSearch($query, $searchQuery = ""): void
    {
        $parsed = $this->parseSearchQuery($searchQuery);

        $included_phrases = $parsed['included_phrases'];
        $included_terms = $parsed['included_terms'];
        $excluded_phrases = $parsed['excluded_phrases'];
        $excluded_terms = $parsed['excluded_terms'];

        $fields = ['business_name', 'email'];

        // Include matches for phrases (unchanged)
        foreach ($included_phrases as $phrase) {
            $phrase = $this->escapeLike($phrase);
            $query->where(function (Builder $q) use ($fields, $phrase) {
                foreach ($fields as $field) {
                    $q->orWhere($field, 'LIKE', "%{$phrase}%");
                }
            });
        }

        // Include matches for terms (with synonyms)
        foreach ($included_terms as $term) {
            $synonyms = $this->getSynonymsForTerm($term);
            $searchTerms = array_unique(array_merge([$term], $synonyms));

            $query->where(function (Builder $q) use ($fields, $searchTerms) {
                foreach ($searchTerms as $searchTerm) {
                    $searchTerm = $this->escapeLike($searchTerm);
                    $q->orWhere(function (Builder $innerQ) use ($fields, $searchTerm) {
                        foreach ($fields as $field) {
                            $innerQ->orWhere($field, 'LIKE', "%{$searchTerm}%");
                        }
                    });
                }
            });
        }

        foreach ($included_terms as $term) {
            $term = $this->escapeLike($term);
            $query->where(function (Builder $q) use ($fields, $term) {
                foreach ($fields as $field) {
                    $q->orWhere($field, 'LIKE', "%{$term}%");
                }
            });
        }

        // Exclude matches for phrases/terms
        foreach ($excluded_phrases as $phrase) {
            $phrase = $this->escapeLike($phrase);
            $query->where(function (Builder $q) use ($fields, $phrase) {
                foreach ($fields as $field) {
                    $q->whereNot($field, 'LIKE', "%{$phrase}%");
                }
            });
        }

        foreach ($excluded_terms as $term) {
            $term = $this->escapeLike($term);
            $query->where(function (Builder $q) use ($fields, $term) {
                foreach ($fields as $field) {
                    $q->whereNot($field, 'LIKE', "%{$term}%");
                }
            });
        }

        return $query;
    }*/


    /*public function scopeSearch($query, $searchQuery = ""): void
    {
        $parsed = $this->parseSearchQuery($searchQuery);

        $included_phrases = $parsed['included_phrases'];
        $included_terms = $parsed['included_terms'];
        $excluded_phrases = $parsed['excluded_phrases'];
        $excluded_terms = $parsed['excluded_terms'];

        $fields = ['business_name', 'email'];

        // Include matches for phrases
        foreach ($included_phrases as $phrase) {
            $phrase = $this->escapeLike($phrase);
            $query->where(function (Builder $q) use ($fields, $phrase) {
                foreach ($fields as $field) {
                    $q->orWhere($field, 'LIKE', "%{$phrase}%");
                }
            });
        }

        // Include matches for terms (with synonyms and partial matching)
        foreach ($included_terms as $term) {
            $synonyms = $this->getSynonymsForTerm($term);
            $searchTerms = array_unique(array_merge([$term], $synonyms));

            $query->where(function (Builder $q) use ($fields, $searchTerms) {
                foreach ($searchTerms as $searchTerm) {
                    $searchTerm = $this->escapeLike($searchTerm);
                    $length = strlen($searchTerm);

                    // Determine base pattern based on term length
                    if ($length <= 3) {
                        $basePattern = "{$searchTerm}%"; // Prefix match for short terms
                    } else {
                        $basePattern = "%{$searchTerm}%"; // Anywhere match for longer terms
                    }

                    // Add base pattern condition
                    $q->orWhere(function (Builder $innerQ) use ($fields, $basePattern) {
                        foreach ($fields as $field) {
                            $innerQ->orWhere($field, 'LIKE', $basePattern);
                        }
                    });

                    // Add stem pattern for terms longer than 5 characters
                    if ($length >= 5) {
                        $stem = substr($searchTerm, 0, 5);
                        $stemPattern = $this->escapeLike($stem) . '%';
                        $q->orWhere(function (Builder $innerQ) use ($fields, $stemPattern) {
                            foreach ($fields as $field) {
                                $innerQ->orWhere($field, 'LIKE', $stemPattern);
                            }
                        });
                    }
                }
            });
        }

        // Exclude matches for phrases and terms
        foreach ($excluded_phrases as $phrase) {
            $phrase = $this->escapeLike($phrase);
            $query->where(function (Builder $q) use ($fields, $phrase) {
                foreach ($fields as $field) {
                    $q->whereNot($field, 'LIKE', "%{$phrase}%");
                }
            });
        }

        foreach ($excluded_terms as $term) {
            $term = $this->escapeLike($term);
            $query->where(function (Builder $q) use ($fields, $term) {
                foreach ($fields as $field) {
                    $q->whereNot($field, 'LIKE', "%{$term}%");
                }
            });
        }
    }*/
}
