import { ref, watch, onMounted, withCtx, createTextVNode, toDisplayString, useSSRContext, mergeProps, unref, createVNode, createBlock, openBlock, Fragment, renderList, createCommentVNode, withDirectives, vModelText } from "vue";
import { ssrRenderAttrs, ssrRenderComponent, ssrInterpolate, ssrRenderList, ssrRenderClass, ssrIncludeBooleanAttr, ssrRenderAttr } from "vue/server-renderer";
import { useToast } from "vue-toastification";
import { IconX, IconUpload, IconCheck, IconTrash, IconWorldUpload, IconSearch } from "@tabler/icons-vue";
import { _ as _sfc_main$2 } from "./AppLayout-CqYed3C-.js";
import axios from "axios";
import { usePage, router, useForm } from "@inertiajs/vue3";
import { _ as _sfc_main$5 } from "./Paginator-Ld42JZuH.js";
import { debounce } from "lodash/function.js";
import { _ as _sfc_main$4 } from "./TableActionMenu-5HE-QJji.js";
import { _ as _sfc_main$6 } from "./PrimaryButton-CvZeXs1Y.js";
import { _ as _sfc_main$3 } from "./Modal-FnzSX7VA.js";
import gsap from "gsap";
import { T as Text, L as LoadingSpinner } from "./LoadingSpinner-DSwZvDHC.js";
import "./_plugin-vue_export-helper-1tPrXgE0.js";
const _sfc_main$1 = {
  __name: "LineProgressBar",
  __ssrInlineRender: true,
  props: {
    progress: String | Number,
    status: String
  },
  setup(__props) {
    const uploadingProcess = ref({ progress: 0 });
    const progressBar = ref(null);
    const props = __props;
    watch(() => props.progress, (newVal) => {
      if (progressBar.value) {
        gsap.to(progressBar.value, { width: `${newVal}%`, duration: 0.5, ease: "power2.out" });
      }
    });
    onMounted(() => {
      let interval = setInterval(() => {
        if (uploadingProcess.value.progress < 100) {
          uploadingProcess.value.progress += 10;
        } else {
          clearInterval(interval);
        }
      }, 500);
    });
    return (_ctx, _push, _parent, _attrs) => {
      if (uploadingProcess.value.progress > 0) {
        _push(`<div${ssrRenderAttrs(_attrs)}><div class="flex w-full h-1.5 bg-gray-200 rounded-full overflow-hidden" role="progressbar" aria-valuenow="25" aria-valuemin="0" aria-valuemax="100"><div class="flex flex-col justify-center rounded-full overflow-hidden bg-blue-600 text-xs text-white text-center whitespace-nowrap transition duration-500 dark:bg-blue-500"></div></div>`);
        if (__props.status) {
          _push(ssrRenderComponent(Text, null, {
            default: withCtx((_, _push2, _parent2, _scopeId) => {
              if (_push2) {
                _push2(`File Data Inserting in ${ssrInterpolate(__props.status)} ${ssrInterpolate(props.progress)}%`);
              } else {
                return [
                  createTextVNode("File Data Inserting in " + toDisplayString(__props.status) + " " + toDisplayString(props.progress) + "%", 1)
                ];
              }
            }),
            _: 1
          }, _parent));
        } else {
          _push(`<!---->`);
        }
        _push(`</div>`);
      } else {
        _push(`<!---->`);
      }
    };
  }
};
const _sfc_setup$1 = _sfc_main$1.setup;
_sfc_main$1.setup = (props, ctx) => {
  const ssrContext = useSSRContext();
  (ssrContext.modules || (ssrContext.modules = /* @__PURE__ */ new Set())).add("resources/js/Components/Ui/Progress/LineProgressBar.vue");
  return _sfc_setup$1 ? _sfc_setup$1(props, ctx) : void 0;
};
const _sfc_main = {
  __name: "List",
  __ssrInlineRender: true,
  setup(__props) {
    const search = ref("");
    const toast = useToast();
    const page = usePage().props;
    const show = ref(false);
    const toggle = () => show.value = !show.value;
    ref({
      name: true,
      price: true,
      currency: true,
      billing_cycle_days: true,
      billing_cycle_type: false,
      product_line: true,
      is_active: false,
      active_subscriptions_count: false,
      expired_subscriptions_count: false
    });
    const uploadingProcess = ref({
      batchId: "",
      progress: "",
      status: "",
      data: []
    });
    onMounted(() => {
      window.Echo.channel("import-progress").listen("ImportProgressUpdated", (event) => {
        uploadingProcess.value = { ...event };
      });
      window.Echo.channel(`uploads.${userId}`).listen("FileUploadProgress", (data) => {
        console.log(data);
        progress.value[data.fileIndex] = data.percent;
      });
    });
    watch(search, debounce((newStr) => {
      router.get(route(route().current()), { q: newStr }, { preserveState: true, replace: true });
    }, 300));
    useForm({
      files: []
    });
    const removeFile = (index) => files.value.splice(index, 1);
    const userId = usePage().props.auth.user.id;
    const getSerialNumber = (index) => (page.data.current_page - 1) * page.data.per_page + index + 1;
    const handleFile = (e) => {
      const input = e.target;
      if (input.files.length > 0) {
        files.value = Array.from(input.files);
      }
    };
    const files = ref([]);
    const progress = ref({});
    const uploading = ref(false);
    const uploadFiles = async () => {
      uploading.value = true;
      const uploadPromises = files.value.map((file, index) => {
        const formData = new FormData();
        formData.append("file", file);
        formData.append("index", index);
        return axios.post(route("admin.data.store"), formData, {
          headers: {
            "Content-Type": "multipart/form-data",
            "X-Requested-With": "XMLHttpRequest"
          }
        });
      });
      try {
        await Promise.all(uploadPromises);
      } catch (error) {
        console.error("Upload error:", error);
      } finally {
        uploading.value = false;
      }
    };
    ref(false);
    watch(() => uploadingProcess.value.status, (newVal) => {
      if (newVal === "completed") {
        setTimeout(() => {
          uploadingProcess.value.progress = "0";
        }, 2e3);
      }
    });
    const reTryFetchData = async () => {
      const response = await axios.post(route("admin.data.start"));
      toast.success(response.data.message);
    };
    return (_ctx, _push, _parent, _attrs) => {
      _push(ssrRenderComponent(_sfc_main$2, mergeProps({ title: "Data Factory List" }, _attrs), {
        header: withCtx((_, _push2, _parent2, _scopeId) => {
          if (_push2) {
            _push2(`<div class="w-full flex justify-between items-center"${_scopeId}><h2 class="font-semibold text-xl text-gray-800 leading-tight"${_scopeId}>Data Factory</h2><div${_scopeId}><button class="mr-5"${_scopeId}>Retry Fetch</button>`);
            _push2(ssrRenderComponent(_sfc_main$6, { onClick: toggle }, {
              default: withCtx((_2, _push3, _parent3, _scopeId2) => {
                if (_push3) {
                  _push3(`Add Data`);
                } else {
                  return [
                    createTextVNode("Add Data")
                  ];
                }
              }),
              _: 1
            }, _parent2, _scopeId));
            _push2(`</div></div>`);
          } else {
            return [
              createVNode("div", { class: "w-full flex justify-between items-center" }, [
                createVNode("h2", { class: "font-semibold text-xl text-gray-800 leading-tight" }, "Data Factory"),
                createVNode("div", null, [
                  createVNode("button", {
                    class: "mr-5",
                    onClick: reTryFetchData
                  }, "Retry Fetch"),
                  createVNode(_sfc_main$6, { onClick: toggle }, {
                    default: withCtx(() => [
                      createTextVNode("Add Data")
                    ]),
                    _: 1
                  })
                ])
              ])
            ];
          }
        }),
        default: withCtx((_, _push2, _parent2, _scopeId) => {
          if (_push2) {
            _push2(ssrRenderComponent(_sfc_main$3, {
              show: show.value,
              onClose: toggle
            }, {
              default: withCtx((_2, _push3, _parent3, _scopeId2) => {
                if (_push3) {
                  _push3(`<div class="w-full relative"${_scopeId2}><div class="w-full flex justify-between items-center px-4 py-3 bg-gray-50 shadow-sm"${_scopeId2}><p${_scopeId2}>Data Import</p><button${_scopeId2}>`);
                  _push3(ssrRenderComponent(unref(IconX), {
                    size: "16",
                    color: "currentColor"
                  }, null, _parent3, _scopeId2));
                  _push3(`</button></div><div${_scopeId2}>`);
                  if (files.value.length) {
                    _push3(`<div class="flex flex-col bg-white rounded-xl"${_scopeId2}><div class="p-4 md:p-5 space-y-7"${_scopeId2}><!--[-->`);
                    ssrRenderList(files.value, (item, index) => {
                      _push3(`<div${_scopeId2}><div class="mb-2 flex justify-between items-center"${_scopeId2}><div class="flex items-center gap-x-3"${_scopeId2}><span class="size-8 flex justify-center items-center border border-gray-200 text-gray-500 rounded-lg dark:border-neutral-700 dark:text-neutral-500"${_scopeId2}>`);
                      _push3(ssrRenderComponent(unref(IconUpload), {
                        size: "20",
                        color: "currentColor"
                      }, null, _parent3, _scopeId2));
                      _push3(`</span><div${_scopeId2}><p class="text-sm font-medium text-gray-800"${_scopeId2}>${ssrInterpolate(item.name)}</p><p class="text-xs text-gray-500 dark:text-neutral-500"${_scopeId2}>${ssrInterpolate(item.size)} KB</p></div></div><div class="inline-flex items-center gap-x-2"${_scopeId2}><span class="${ssrRenderClass(`relative ${progress.value[index] > 95 ? "text-green-600" : "text-gray-600"}`)}"${_scopeId2}>`);
                      _push3(ssrRenderComponent(unref(IconCheck), {
                        color: "currentColor",
                        size: "17"
                      }, null, _parent3, _scopeId2));
                      _push3(`<span class="sr-only"${_scopeId2}>Success</span></span><button type="button" class="relative text-gray-500 hover:text-gray-800 focus:outline-hidden focus:text-gray-800 disabled:opacity-50 disabled:pointer-events-none dark:text-neutral-500 dark:hover:text-neutral-200 dark:focus:text-neutral-200"${_scopeId2}>`);
                      _push3(ssrRenderComponent(unref(IconTrash), {
                        size: "15",
                        color: "currentColor"
                      }, null, _parent3, _scopeId2));
                      _push3(`<span class="sr-only"${_scopeId2}>Delete</span></button></div></div>`);
                      _push3(ssrRenderComponent(_sfc_main$1, {
                        progress: progress.value[index]
                      }, null, _parent3, _scopeId2));
                      _push3(`</div>`);
                    });
                    _push3(`<!--]--></div><div class="bg-gray-50 border-t border-gray-200 py-2 px-4 md:px-5"${_scopeId2}><div class="flex flex-wrap justify-between items-center gap-x-3"${_scopeId2}><div${_scopeId2}><span class="text-sm font-semibold text-gray-800"${_scopeId2}>${ssrInterpolate(files.value.length)} Total</span></div><div class="-me-2.5"${_scopeId2}><button${ssrIncludeBooleanAttr(uploading.value) ? " disabled" : ""} type="button" class="py-2 px-3 inline-flex items-center gap-x-1.5 text-sm font-medium rounded-lg border border-transparent text-gray-500 hover:bg-gray-200 hover:text-gray-800 focus:outline-hidden focus:bg-gray-200 focus:text-gray-800 disabled:opacity-50 disabled:pointer-events-none dark:text-neutral-400 dark:hover:bg-neutral-800 dark:hover:text-white dark:focus:bg-neutral-800 dark:focus:text-white"${_scopeId2}>`);
                    if (!uploading.value) {
                      _push3(`<span class="flex gap-1 items-center justify-center"${_scopeId2}>`);
                      _push3(ssrRenderComponent(unref(IconWorldUpload), {
                        size: "15",
                        color: "currentColor"
                      }, null, _parent3, _scopeId2));
                      _push3(`<span${_scopeId2}>Start Uploading</span></span>`);
                    } else {
                      _push3(`<span class="flex items-center justify-center gap-2"${_scopeId2}>`);
                      _push3(ssrRenderComponent(LoadingSpinner, null, null, _parent3, _scopeId2));
                      _push3(` Processing... </span>`);
                    }
                    _push3(`</button><button${ssrIncludeBooleanAttr(uploading.value) ? " disabled" : ""} type="button" class="py-2 px-3 inline-flex items-center gap-x-1.5 text-sm font-medium rounded-lg border border-transparent text-gray-500 hover:bg-gray-200 hover:text-gray-800 focus:outline-hidden focus:bg-gray-200 focus:text-gray-800 disabled:opacity-50 disabled:pointer-events-none dark:text-neutral-400 dark:hover:bg-neutral-800 dark:hover:text-white dark:focus:bg-neutral-800 dark:focus:text-white"${_scopeId2}>`);
                    _push3(ssrRenderComponent(unref(IconTrash), {
                      size: "15",
                      color: "currentColor"
                    }, null, _parent3, _scopeId2));
                    _push3(` Delete </button></div></div></div></div>`);
                  } else {
                    _push3(`<div class="px-5 py-6 w-full py-9 bg-gray-50 rounded-2xl border border-gray-300 gap-3 grid border-dashed"${_scopeId2}><div class="grid gap-1"${_scopeId2}><svg class="mx-auto" width="40" height="40" viewBox="0 0 40 40" fill="none" xmlns="http://www.w3.org/2000/svg"${_scopeId2}><g id="File"${_scopeId2}><path id="icon" d="M31.6497 10.6056L32.2476 10.0741L31.6497 10.6056ZM28.6559 7.23757L28.058 7.76907L28.058 7.76907L28.6559 7.23757ZM26.5356 5.29253L26.2079 6.02233L26.2079 6.02233L26.5356 5.29253ZM33.1161 12.5827L32.3683 12.867V12.867L33.1161 12.5827ZM31.8692 33.5355L32.4349 34.1012L31.8692 33.5355ZM24.231 11.4836L25.0157 11.3276L24.231 11.4836ZM26.85 14.1026L26.694 14.8872L26.85 14.1026ZM11.667 20.8667C11.2252 20.8667 10.867 21.2248 10.867 21.6667C10.867 22.1085 11.2252 22.4667 11.667 22.4667V20.8667ZM25.0003 22.4667C25.4422 22.4667 25.8003 22.1085 25.8003 21.6667C25.8003 21.2248 25.4422 20.8667 25.0003 20.8667V22.4667ZM11.667 25.8667C11.2252 25.8667 10.867 26.2248 10.867 26.6667C10.867 27.1085 11.2252 27.4667 11.667 27.4667V25.8667ZM20.0003 27.4667C20.4422 27.4667 20.8003 27.1085 20.8003 26.6667C20.8003 26.2248 20.4422 25.8667 20.0003 25.8667V27.4667ZM23.3337 34.2H16.667V35.8H23.3337V34.2ZM7.46699 25V15H5.86699V25H7.46699ZM32.5337 15.0347V25H34.1337V15.0347H32.5337ZM16.667 5.8H23.6732V4.2H16.667V5.8ZM23.6732 5.8C25.2185 5.8 25.7493 5.81639 26.2079 6.02233L26.8633 4.56274C26.0191 4.18361 25.0759 4.2 23.6732 4.2V5.8ZM29.2539 6.70608C28.322 5.65771 27.7076 4.94187 26.8633 4.56274L26.2079 6.02233C26.6665 6.22826 27.0314 6.6141 28.058 7.76907L29.2539 6.70608ZM34.1337 15.0347C34.1337 13.8411 34.1458 13.0399 33.8638 12.2984L32.3683 12.867C32.5216 13.2702 32.5337 13.7221 32.5337 15.0347H34.1337ZM31.0518 11.1371C31.9238 12.1181 32.215 12.4639 32.3683 12.867L33.8638 12.2984C33.5819 11.5569 33.0406 10.9662 32.2476 10.0741L31.0518 11.1371ZM16.667 34.2C14.2874 34.2 12.5831 34.1983 11.2872 34.0241C10.0144 33.8529 9.25596 33.5287 8.69714 32.9698L7.56577 34.1012C8.47142 35.0069 9.62375 35.4148 11.074 35.6098C12.5013 35.8017 14.3326 35.8 16.667 35.8V34.2ZM5.86699 25C5.86699 27.3344 5.86529 29.1657 6.05718 30.593C6.25217 32.0432 6.66012 33.1956 7.56577 34.1012L8.69714 32.9698C8.13833 32.411 7.81405 31.6526 7.64292 30.3798C7.46869 29.0839 7.46699 27.3796 7.46699 25H5.86699ZM23.3337 35.8C25.6681 35.8 27.4993 35.8017 28.9266 35.6098C30.3769 35.4148 31.5292 35.0069 32.4349 34.1012L31.3035 32.9698C30.7447 33.5287 29.9863 33.8529 28.7134 34.0241C27.4175 34.1983 25.7133 34.2 23.3337 34.2V35.8ZM32.5337 25C32.5337 27.3796 32.532 29.0839 32.3577 30.3798C32.1866 31.6526 31.8623 32.411 31.3035 32.9698L32.4349 34.1012C33.3405 33.1956 33.7485 32.0432 33.9435 30.593C34.1354 29.1657 34.1337 27.3344 34.1337 25H32.5337ZM7.46699 15C7.46699 12.6204 7.46869 10.9161 7.64292 9.62024C7.81405 8.34738 8.13833 7.58897 8.69714 7.03015L7.56577 5.89878C6.66012 6.80443 6.25217 7.95676 6.05718 9.40704C5.86529 10.8343 5.86699 12.6656 5.86699 15H7.46699ZM16.667 4.2C14.3326 4.2 12.5013 4.1983 11.074 4.39019C9.62375 4.58518 8.47142 4.99313 7.56577 5.89878L8.69714 7.03015C9.25596 6.47133 10.0144 6.14706 11.2872 5.97592C12.5831 5.8017 14.2874 5.8 16.667 5.8V4.2ZM23.367 5V10H24.967V5H23.367ZM28.3337 14.9667H33.3337V13.3667H28.3337V14.9667ZM23.367 10C23.367 10.7361 23.3631 11.221 23.4464 11.6397L25.0157 11.3276C24.9709 11.1023 24.967 10.8128 24.967 10H23.367ZM28.3337 13.3667C27.5209 13.3667 27.2313 13.3628 27.0061 13.318L26.694 14.8872C27.1127 14.9705 27.5976 14.9667 28.3337 14.9667V13.3667ZM23.4464 11.6397C23.7726 13.2794 25.0543 14.5611 26.694 14.8872L27.0061 13.318C26.0011 13.1181 25.2156 12.3325 25.0157 11.3276L23.4464 11.6397ZM11.667 22.4667H25.0003V20.8667H11.667V22.4667ZM11.667 27.4667H20.0003V25.8667H11.667V27.4667ZM32.2476 10.0741L29.2539 6.70608L28.058 7.76907L31.0518 11.1371L32.2476 10.0741Z" fill="#4F46E5"${_scopeId2}></path></g></svg><h2 class="text-center text-gray-400 text-xs leading-4"${_scopeId2}>XLS, XLSX or CSV, smaller than 15MB</h2></div><div class="grid gap-2"${_scopeId2}><h4 class="text-center text-gray-900 text-sm font-medium leading-snug"${_scopeId2}>Drag and Drop your file here or</h4><div class="flex items-center justify-center"${_scopeId2}><label${_scopeId2}><input type="file" hidden multiple${_scopeId2}><div class="flex w-28 h-9 px-2 flex-col bg-indigo-600 rounded-full shadow text-white text-xs font-semibold leading-4 items-center justify-center cursor-pointer focus:outline-none"${_scopeId2}>Choose File</div></label></div></div></div>`);
                  }
                  _push3(`</div></div>`);
                } else {
                  return [
                    createVNode("div", { class: "w-full relative" }, [
                      createVNode("div", { class: "w-full flex justify-between items-center px-4 py-3 bg-gray-50 shadow-sm" }, [
                        createVNode("p", null, "Data Import"),
                        createVNode("button", { onClick: toggle }, [
                          createVNode(unref(IconX), {
                            size: "16",
                            color: "currentColor"
                          })
                        ])
                      ]),
                      createVNode("div", null, [
                        files.value.length ? (openBlock(), createBlock("div", {
                          key: 0,
                          class: "flex flex-col bg-white rounded-xl"
                        }, [
                          createVNode("div", { class: "p-4 md:p-5 space-y-7" }, [
                            (openBlock(true), createBlock(Fragment, null, renderList(files.value, (item, index) => {
                              return openBlock(), createBlock("div", {
                                key: `selected-file-${index}`
                              }, [
                                createVNode("div", { class: "mb-2 flex justify-between items-center" }, [
                                  createVNode("div", { class: "flex items-center gap-x-3" }, [
                                    createVNode("span", { class: "size-8 flex justify-center items-center border border-gray-200 text-gray-500 rounded-lg dark:border-neutral-700 dark:text-neutral-500" }, [
                                      createVNode(unref(IconUpload), {
                                        size: "20",
                                        color: "currentColor"
                                      })
                                    ]),
                                    createVNode("div", null, [
                                      createVNode("p", { class: "text-sm font-medium text-gray-800" }, toDisplayString(item.name), 1),
                                      createVNode("p", { class: "text-xs text-gray-500 dark:text-neutral-500" }, toDisplayString(item.size) + " KB", 1)
                                    ])
                                  ]),
                                  createVNode("div", { class: "inline-flex items-center gap-x-2" }, [
                                    createVNode("span", {
                                      class: `relative ${progress.value[index] > 95 ? "text-green-600" : "text-gray-600"}`
                                    }, [
                                      createVNode(unref(IconCheck), {
                                        color: "currentColor",
                                        size: "17"
                                      }),
                                      createVNode("span", { class: "sr-only" }, "Success")
                                    ], 2),
                                    createVNode("button", {
                                      type: "button",
                                      onClick: () => removeFile(index),
                                      class: "relative text-gray-500 hover:text-gray-800 focus:outline-hidden focus:text-gray-800 disabled:opacity-50 disabled:pointer-events-none dark:text-neutral-500 dark:hover:text-neutral-200 dark:focus:text-neutral-200"
                                    }, [
                                      createVNode(unref(IconTrash), {
                                        size: "15",
                                        color: "currentColor"
                                      }),
                                      createVNode("span", { class: "sr-only" }, "Delete")
                                    ], 8, ["onClick"])
                                  ])
                                ]),
                                createVNode(_sfc_main$1, {
                                  progress: progress.value[index]
                                }, null, 8, ["progress"])
                              ]);
                            }), 128))
                          ]),
                          createVNode("div", { class: "bg-gray-50 border-t border-gray-200 py-2 px-4 md:px-5" }, [
                            createVNode("div", { class: "flex flex-wrap justify-between items-center gap-x-3" }, [
                              createVNode("div", null, [
                                createVNode("span", { class: "text-sm font-semibold text-gray-800" }, toDisplayString(files.value.length) + " Total", 1)
                              ]),
                              createVNode("div", { class: "-me-2.5" }, [
                                createVNode("button", {
                                  onClick: uploadFiles,
                                  disabled: uploading.value,
                                  type: "button",
                                  class: "py-2 px-3 inline-flex items-center gap-x-1.5 text-sm font-medium rounded-lg border border-transparent text-gray-500 hover:bg-gray-200 hover:text-gray-800 focus:outline-hidden focus:bg-gray-200 focus:text-gray-800 disabled:opacity-50 disabled:pointer-events-none dark:text-neutral-400 dark:hover:bg-neutral-800 dark:hover:text-white dark:focus:bg-neutral-800 dark:focus:text-white"
                                }, [
                                  !uploading.value ? (openBlock(), createBlock("span", {
                                    key: 0,
                                    class: "flex gap-1 items-center justify-center"
                                  }, [
                                    createVNode(unref(IconWorldUpload), {
                                      size: "15",
                                      color: "currentColor"
                                    }),
                                    createVNode("span", null, "Start Uploading")
                                  ])) : (openBlock(), createBlock("span", {
                                    key: 1,
                                    class: "flex items-center justify-center gap-2"
                                  }, [
                                    createVNode(LoadingSpinner),
                                    createTextVNode(" Processing... ")
                                  ]))
                                ], 8, ["disabled"]),
                                createVNode("button", {
                                  disabled: uploading.value,
                                  type: "button",
                                  class: "py-2 px-3 inline-flex items-center gap-x-1.5 text-sm font-medium rounded-lg border border-transparent text-gray-500 hover:bg-gray-200 hover:text-gray-800 focus:outline-hidden focus:bg-gray-200 focus:text-gray-800 disabled:opacity-50 disabled:pointer-events-none dark:text-neutral-400 dark:hover:bg-neutral-800 dark:hover:text-white dark:focus:bg-neutral-800 dark:focus:text-white"
                                }, [
                                  createVNode(unref(IconTrash), {
                                    size: "15",
                                    color: "currentColor"
                                  }),
                                  createTextVNode(" Delete ")
                                ], 8, ["disabled"])
                              ])
                            ])
                          ])
                        ])) : (openBlock(), createBlock("div", {
                          key: 1,
                          class: "px-5 py-6 w-full py-9 bg-gray-50 rounded-2xl border border-gray-300 gap-3 grid border-dashed"
                        }, [
                          createVNode("div", { class: "grid gap-1" }, [
                            (openBlock(), createBlock("svg", {
                              class: "mx-auto",
                              width: "40",
                              height: "40",
                              viewBox: "0 0 40 40",
                              fill: "none",
                              xmlns: "http://www.w3.org/2000/svg"
                            }, [
                              createVNode("g", { id: "File" }, [
                                createVNode("path", {
                                  id: "icon",
                                  d: "M31.6497 10.6056L32.2476 10.0741L31.6497 10.6056ZM28.6559 7.23757L28.058 7.76907L28.058 7.76907L28.6559 7.23757ZM26.5356 5.29253L26.2079 6.02233L26.2079 6.02233L26.5356 5.29253ZM33.1161 12.5827L32.3683 12.867V12.867L33.1161 12.5827ZM31.8692 33.5355L32.4349 34.1012L31.8692 33.5355ZM24.231 11.4836L25.0157 11.3276L24.231 11.4836ZM26.85 14.1026L26.694 14.8872L26.85 14.1026ZM11.667 20.8667C11.2252 20.8667 10.867 21.2248 10.867 21.6667C10.867 22.1085 11.2252 22.4667 11.667 22.4667V20.8667ZM25.0003 22.4667C25.4422 22.4667 25.8003 22.1085 25.8003 21.6667C25.8003 21.2248 25.4422 20.8667 25.0003 20.8667V22.4667ZM11.667 25.8667C11.2252 25.8667 10.867 26.2248 10.867 26.6667C10.867 27.1085 11.2252 27.4667 11.667 27.4667V25.8667ZM20.0003 27.4667C20.4422 27.4667 20.8003 27.1085 20.8003 26.6667C20.8003 26.2248 20.4422 25.8667 20.0003 25.8667V27.4667ZM23.3337 34.2H16.667V35.8H23.3337V34.2ZM7.46699 25V15H5.86699V25H7.46699ZM32.5337 15.0347V25H34.1337V15.0347H32.5337ZM16.667 5.8H23.6732V4.2H16.667V5.8ZM23.6732 5.8C25.2185 5.8 25.7493 5.81639 26.2079 6.02233L26.8633 4.56274C26.0191 4.18361 25.0759 4.2 23.6732 4.2V5.8ZM29.2539 6.70608C28.322 5.65771 27.7076 4.94187 26.8633 4.56274L26.2079 6.02233C26.6665 6.22826 27.0314 6.6141 28.058 7.76907L29.2539 6.70608ZM34.1337 15.0347C34.1337 13.8411 34.1458 13.0399 33.8638 12.2984L32.3683 12.867C32.5216 13.2702 32.5337 13.7221 32.5337 15.0347H34.1337ZM31.0518 11.1371C31.9238 12.1181 32.215 12.4639 32.3683 12.867L33.8638 12.2984C33.5819 11.5569 33.0406 10.9662 32.2476 10.0741L31.0518 11.1371ZM16.667 34.2C14.2874 34.2 12.5831 34.1983 11.2872 34.0241C10.0144 33.8529 9.25596 33.5287 8.69714 32.9698L7.56577 34.1012C8.47142 35.0069 9.62375 35.4148 11.074 35.6098C12.5013 35.8017 14.3326 35.8 16.667 35.8V34.2ZM5.86699 25C5.86699 27.3344 5.86529 29.1657 6.05718 30.593C6.25217 32.0432 6.66012 33.1956 7.56577 34.1012L8.69714 32.9698C8.13833 32.411 7.81405 31.6526 7.64292 30.3798C7.46869 29.0839 7.46699 27.3796 7.46699 25H5.86699ZM23.3337 35.8C25.6681 35.8 27.4993 35.8017 28.9266 35.6098C30.3769 35.4148 31.5292 35.0069 32.4349 34.1012L31.3035 32.9698C30.7447 33.5287 29.9863 33.8529 28.7134 34.0241C27.4175 34.1983 25.7133 34.2 23.3337 34.2V35.8ZM32.5337 25C32.5337 27.3796 32.532 29.0839 32.3577 30.3798C32.1866 31.6526 31.8623 32.411 31.3035 32.9698L32.4349 34.1012C33.3405 33.1956 33.7485 32.0432 33.9435 30.593C34.1354 29.1657 34.1337 27.3344 34.1337 25H32.5337ZM7.46699 15C7.46699 12.6204 7.46869 10.9161 7.64292 9.62024C7.81405 8.34738 8.13833 7.58897 8.69714 7.03015L7.56577 5.89878C6.66012 6.80443 6.25217 7.95676 6.05718 9.40704C5.86529 10.8343 5.86699 12.6656 5.86699 15H7.46699ZM16.667 4.2C14.3326 4.2 12.5013 4.1983 11.074 4.39019C9.62375 4.58518 8.47142 4.99313 7.56577 5.89878L8.69714 7.03015C9.25596 6.47133 10.0144 6.14706 11.2872 5.97592C12.5831 5.8017 14.2874 5.8 16.667 5.8V4.2ZM23.367 5V10H24.967V5H23.367ZM28.3337 14.9667H33.3337V13.3667H28.3337V14.9667ZM23.367 10C23.367 10.7361 23.3631 11.221 23.4464 11.6397L25.0157 11.3276C24.9709 11.1023 24.967 10.8128 24.967 10H23.367ZM28.3337 13.3667C27.5209 13.3667 27.2313 13.3628 27.0061 13.318L26.694 14.8872C27.1127 14.9705 27.5976 14.9667 28.3337 14.9667V13.3667ZM23.4464 11.6397C23.7726 13.2794 25.0543 14.5611 26.694 14.8872L27.0061 13.318C26.0011 13.1181 25.2156 12.3325 25.0157 11.3276L23.4464 11.6397ZM11.667 22.4667H25.0003V20.8667H11.667V22.4667ZM11.667 27.4667H20.0003V25.8667H11.667V27.4667ZM32.2476 10.0741L29.2539 6.70608L28.058 7.76907L31.0518 11.1371L32.2476 10.0741Z",
                                  fill: "#4F46E5"
                                })
                              ])
                            ])),
                            createVNode("h2", { class: "text-center text-gray-400 text-xs leading-4" }, "XLS, XLSX or CSV, smaller than 15MB")
                          ]),
                          createVNode("div", { class: "grid gap-2" }, [
                            createVNode("h4", { class: "text-center text-gray-900 text-sm font-medium leading-snug" }, "Drag and Drop your file here or"),
                            createVNode("div", { class: "flex items-center justify-center" }, [
                              createVNode("label", null, [
                                createVNode("input", {
                                  type: "file",
                                  onChange: handleFile,
                                  hidden: "",
                                  multiple: ""
                                }, null, 32),
                                createVNode("div", { class: "flex w-28 h-9 px-2 flex-col bg-indigo-600 rounded-full shadow text-white text-xs font-semibold leading-4 items-center justify-center cursor-pointer focus:outline-none" }, "Choose File")
                              ])
                            ])
                          ])
                        ]))
                      ])
                    ])
                  ];
                }
              }),
              _: 1
            }, _parent2, _scopeId));
            _push2(`<div class="py-12"${_scopeId}><div class="max-w-7xl mx-auto sm:px-6 lg:px-8"${_scopeId}>${ssrInterpolate(_ctx.$page.props.tempUploadedFiles)} `);
            if (uploadingProcess.value.progress > 0) {
              _push2(ssrRenderComponent(_sfc_main$1, {
                status: uploadingProcess.value.status,
                progress: uploadingProcess.value.progress
              }, null, _parent2, _scopeId));
            } else {
              _push2(`<!---->`);
            }
            _push2(`<div class="pb-4 w-full flex justify-between items-center"${_scopeId}><p class="text-gray-700 text-lg font-semibold"${_scopeId}>List</p><div class="relative"${_scopeId}><div class="absolute flex items-center justify-center h-full px-2 text-gray-500 bg-gray-100 rounded-md"${_scopeId}>`);
            _push2(ssrRenderComponent(unref(IconSearch), {
              size: "20",
              color: "currentColor"
            }, null, _parent2, _scopeId));
            _push2(`</div><input${ssrRenderAttr("value", search.value)} class="bg-white pl-10 text-sm w-52 shadow outline-none border-none focus:border-none focus:ring-1 focus:ring-gray-300 rounded-md" placeholder="Search..."${_scopeId}></div></div><div class="rounded-md shadow-sm h-full"${_scopeId}><table class="w-full capitalize"${_scopeId}><thead class="bg-white border-b-2 border-gray-100"${_scopeId}><tr${_scopeId}><th class="w-8 p-3 text-sm text-gray-800 font-semibold tracking-wide text-left"${_scopeId}>Sl</th><th class="w-28 p-3 text-sm text-gray-800 font-semibold tracking-wide text-left"${_scopeId}>Cell Number </th><th class="w-36 p-3 text-sm text-gray-800 font-semibold tracking-wide text-left"${_scopeId}>Business Name </th><th class="w-20 p-3 text-sm text-gray-800 font-semibold tracking-wide text-left"${_scopeId}>First Name </th><th class="w-20 p-3 text-sm text-gray-800 font-semibold tracking-wide text-left"${_scopeId}>Last Name </th><th class="w-24 p-3 text-sm text-gray-800 font-semibold tracking-wide text-left"${_scopeId}>E-Mail</th><th class="w-24 p-3 text-sm text-gray-800 font-semibold tracking-wide text-left"${_scopeId}>Website </th><th class="w-24 p-3 text-sm text-gray-800 font-semibold tracking-wide text-left"${_scopeId}>City</th><th class="w-24 p-3 text-sm text-gray-800 font-semibold tracking-wide text-left"${_scopeId}>State</th><th class="w-24 p-3 text-sm text-gray-800 font-semibold tracking-wide text-left"${_scopeId}>Business Address </th><th class="w-24 p-3 text-sm text-gray-800 font-semibold tracking-wide text-left"${_scopeId}>Pin Code </th><th class="w-20 p-3 text-sm text-gray-800 font-semibold tracking-wide text-left"${_scopeId}>Actions </th></tr></thead><tbody${_scopeId}><!--[-->`);
            ssrRenderList(_ctx.$page.props.data.data, (item, index) => {
              _push2(`<tr class="${ssrRenderClass([index % 2 === 1 ? "bg-white" : "bg-gray-50", "group"])}"${_scopeId}><td class="p-3 text-sm text-gray-700 group-hover:text-blue-500 group-hover:underline font-bold"${_scopeId}>${ssrInterpolate(getSerialNumber(index))}</td><td class="p-3 text-sm text-gray-700"${_scopeId}>${ssrInterpolate(item.cell_number)}</td><td class="p-3 text-sm text-gray-700"${_scopeId}>${ssrInterpolate(item.business_name)}</td><td class="p-3 text-sm text-gray-700"${_scopeId}>${ssrInterpolate(item.first_name)}</td><td class="p-3 text-sm text-gray-700"${_scopeId}>${ssrInterpolate(item.last_name)}</td><td class="p-3 text-sm text-gray-700"${_scopeId}>${ssrInterpolate(item.email)}</td><td class="p-3 text-sm text-gray-700"${_scopeId}>${ssrInterpolate(item.website)}</td><td class="p-3 text-sm text-gray-700"${_scopeId}>${ssrInterpolate(item.city)}</td><td class="p-3 text-sm text-gray-700"${_scopeId}>${ssrInterpolate(item.state)}</td><td class="p-3 text-sm text-gray-700"${_scopeId}>${ssrInterpolate(item.business_address)}</td><td class="p-3 text-sm text-gray-700"${_scopeId}>${ssrInterpolate(item.pin_code)}</td><td class="p-3 text-sm text-gray-700"${_scopeId}>`);
              _push2(ssrRenderComponent(_sfc_main$4, null, null, _parent2, _scopeId));
              _push2(`</td></tr>`);
            });
            _push2(`<!--]-->`);
            if (search.value && !_ctx.$page.props.data.data.length) {
              _push2(`<tr class="${ssrRenderClass(["bg-white group"])}"${_scopeId}><td class="p-3 text-sm text-gray-700 text-center" colspan="12"${_scopeId}>Not found data by this \`${ssrInterpolate(search.value)}\` </td></tr>`);
            } else {
              _push2(`<!---->`);
            }
            if (!search.value && !_ctx.$page.props.data.data.length) {
              _push2(`<tr class="${ssrRenderClass(["bg-white group"])}"${_scopeId}><td class="p-3 text-sm text-gray-700 text-center" colspan="12"${_scopeId}>Empty</td></tr>`);
            } else {
              _push2(`<!---->`);
            }
            _push2(`</tbody></table></div>`);
            if (_ctx.$page.props.data.data.length) {
              _push2(ssrRenderComponent(_sfc_main$5, {
                from: _ctx.$page.props.data.from,
                to: _ctx.$page.props.data.to,
                total: _ctx.$page.props.data.total,
                links: _ctx.$page.props.data.links,
                class: "mt-6"
              }, null, _parent2, _scopeId));
            } else {
              _push2(`<!---->`);
            }
            _push2(`</div></div>`);
          } else {
            return [
              createVNode(_sfc_main$3, {
                show: show.value,
                onClose: toggle
              }, {
                default: withCtx(() => [
                  createVNode("div", { class: "w-full relative" }, [
                    createVNode("div", { class: "w-full flex justify-between items-center px-4 py-3 bg-gray-50 shadow-sm" }, [
                      createVNode("p", null, "Data Import"),
                      createVNode("button", { onClick: toggle }, [
                        createVNode(unref(IconX), {
                          size: "16",
                          color: "currentColor"
                        })
                      ])
                    ]),
                    createVNode("div", null, [
                      files.value.length ? (openBlock(), createBlock("div", {
                        key: 0,
                        class: "flex flex-col bg-white rounded-xl"
                      }, [
                        createVNode("div", { class: "p-4 md:p-5 space-y-7" }, [
                          (openBlock(true), createBlock(Fragment, null, renderList(files.value, (item, index) => {
                            return openBlock(), createBlock("div", {
                              key: `selected-file-${index}`
                            }, [
                              createVNode("div", { class: "mb-2 flex justify-between items-center" }, [
                                createVNode("div", { class: "flex items-center gap-x-3" }, [
                                  createVNode("span", { class: "size-8 flex justify-center items-center border border-gray-200 text-gray-500 rounded-lg dark:border-neutral-700 dark:text-neutral-500" }, [
                                    createVNode(unref(IconUpload), {
                                      size: "20",
                                      color: "currentColor"
                                    })
                                  ]),
                                  createVNode("div", null, [
                                    createVNode("p", { class: "text-sm font-medium text-gray-800" }, toDisplayString(item.name), 1),
                                    createVNode("p", { class: "text-xs text-gray-500 dark:text-neutral-500" }, toDisplayString(item.size) + " KB", 1)
                                  ])
                                ]),
                                createVNode("div", { class: "inline-flex items-center gap-x-2" }, [
                                  createVNode("span", {
                                    class: `relative ${progress.value[index] > 95 ? "text-green-600" : "text-gray-600"}`
                                  }, [
                                    createVNode(unref(IconCheck), {
                                      color: "currentColor",
                                      size: "17"
                                    }),
                                    createVNode("span", { class: "sr-only" }, "Success")
                                  ], 2),
                                  createVNode("button", {
                                    type: "button",
                                    onClick: () => removeFile(index),
                                    class: "relative text-gray-500 hover:text-gray-800 focus:outline-hidden focus:text-gray-800 disabled:opacity-50 disabled:pointer-events-none dark:text-neutral-500 dark:hover:text-neutral-200 dark:focus:text-neutral-200"
                                  }, [
                                    createVNode(unref(IconTrash), {
                                      size: "15",
                                      color: "currentColor"
                                    }),
                                    createVNode("span", { class: "sr-only" }, "Delete")
                                  ], 8, ["onClick"])
                                ])
                              ]),
                              createVNode(_sfc_main$1, {
                                progress: progress.value[index]
                              }, null, 8, ["progress"])
                            ]);
                          }), 128))
                        ]),
                        createVNode("div", { class: "bg-gray-50 border-t border-gray-200 py-2 px-4 md:px-5" }, [
                          createVNode("div", { class: "flex flex-wrap justify-between items-center gap-x-3" }, [
                            createVNode("div", null, [
                              createVNode("span", { class: "text-sm font-semibold text-gray-800" }, toDisplayString(files.value.length) + " Total", 1)
                            ]),
                            createVNode("div", { class: "-me-2.5" }, [
                              createVNode("button", {
                                onClick: uploadFiles,
                                disabled: uploading.value,
                                type: "button",
                                class: "py-2 px-3 inline-flex items-center gap-x-1.5 text-sm font-medium rounded-lg border border-transparent text-gray-500 hover:bg-gray-200 hover:text-gray-800 focus:outline-hidden focus:bg-gray-200 focus:text-gray-800 disabled:opacity-50 disabled:pointer-events-none dark:text-neutral-400 dark:hover:bg-neutral-800 dark:hover:text-white dark:focus:bg-neutral-800 dark:focus:text-white"
                              }, [
                                !uploading.value ? (openBlock(), createBlock("span", {
                                  key: 0,
                                  class: "flex gap-1 items-center justify-center"
                                }, [
                                  createVNode(unref(IconWorldUpload), {
                                    size: "15",
                                    color: "currentColor"
                                  }),
                                  createVNode("span", null, "Start Uploading")
                                ])) : (openBlock(), createBlock("span", {
                                  key: 1,
                                  class: "flex items-center justify-center gap-2"
                                }, [
                                  createVNode(LoadingSpinner),
                                  createTextVNode(" Processing... ")
                                ]))
                              ], 8, ["disabled"]),
                              createVNode("button", {
                                disabled: uploading.value,
                                type: "button",
                                class: "py-2 px-3 inline-flex items-center gap-x-1.5 text-sm font-medium rounded-lg border border-transparent text-gray-500 hover:bg-gray-200 hover:text-gray-800 focus:outline-hidden focus:bg-gray-200 focus:text-gray-800 disabled:opacity-50 disabled:pointer-events-none dark:text-neutral-400 dark:hover:bg-neutral-800 dark:hover:text-white dark:focus:bg-neutral-800 dark:focus:text-white"
                              }, [
                                createVNode(unref(IconTrash), {
                                  size: "15",
                                  color: "currentColor"
                                }),
                                createTextVNode(" Delete ")
                              ], 8, ["disabled"])
                            ])
                          ])
                        ])
                      ])) : (openBlock(), createBlock("div", {
                        key: 1,
                        class: "px-5 py-6 w-full py-9 bg-gray-50 rounded-2xl border border-gray-300 gap-3 grid border-dashed"
                      }, [
                        createVNode("div", { class: "grid gap-1" }, [
                          (openBlock(), createBlock("svg", {
                            class: "mx-auto",
                            width: "40",
                            height: "40",
                            viewBox: "0 0 40 40",
                            fill: "none",
                            xmlns: "http://www.w3.org/2000/svg"
                          }, [
                            createVNode("g", { id: "File" }, [
                              createVNode("path", {
                                id: "icon",
                                d: "M31.6497 10.6056L32.2476 10.0741L31.6497 10.6056ZM28.6559 7.23757L28.058 7.76907L28.058 7.76907L28.6559 7.23757ZM26.5356 5.29253L26.2079 6.02233L26.2079 6.02233L26.5356 5.29253ZM33.1161 12.5827L32.3683 12.867V12.867L33.1161 12.5827ZM31.8692 33.5355L32.4349 34.1012L31.8692 33.5355ZM24.231 11.4836L25.0157 11.3276L24.231 11.4836ZM26.85 14.1026L26.694 14.8872L26.85 14.1026ZM11.667 20.8667C11.2252 20.8667 10.867 21.2248 10.867 21.6667C10.867 22.1085 11.2252 22.4667 11.667 22.4667V20.8667ZM25.0003 22.4667C25.4422 22.4667 25.8003 22.1085 25.8003 21.6667C25.8003 21.2248 25.4422 20.8667 25.0003 20.8667V22.4667ZM11.667 25.8667C11.2252 25.8667 10.867 26.2248 10.867 26.6667C10.867 27.1085 11.2252 27.4667 11.667 27.4667V25.8667ZM20.0003 27.4667C20.4422 27.4667 20.8003 27.1085 20.8003 26.6667C20.8003 26.2248 20.4422 25.8667 20.0003 25.8667V27.4667ZM23.3337 34.2H16.667V35.8H23.3337V34.2ZM7.46699 25V15H5.86699V25H7.46699ZM32.5337 15.0347V25H34.1337V15.0347H32.5337ZM16.667 5.8H23.6732V4.2H16.667V5.8ZM23.6732 5.8C25.2185 5.8 25.7493 5.81639 26.2079 6.02233L26.8633 4.56274C26.0191 4.18361 25.0759 4.2 23.6732 4.2V5.8ZM29.2539 6.70608C28.322 5.65771 27.7076 4.94187 26.8633 4.56274L26.2079 6.02233C26.6665 6.22826 27.0314 6.6141 28.058 7.76907L29.2539 6.70608ZM34.1337 15.0347C34.1337 13.8411 34.1458 13.0399 33.8638 12.2984L32.3683 12.867C32.5216 13.2702 32.5337 13.7221 32.5337 15.0347H34.1337ZM31.0518 11.1371C31.9238 12.1181 32.215 12.4639 32.3683 12.867L33.8638 12.2984C33.5819 11.5569 33.0406 10.9662 32.2476 10.0741L31.0518 11.1371ZM16.667 34.2C14.2874 34.2 12.5831 34.1983 11.2872 34.0241C10.0144 33.8529 9.25596 33.5287 8.69714 32.9698L7.56577 34.1012C8.47142 35.0069 9.62375 35.4148 11.074 35.6098C12.5013 35.8017 14.3326 35.8 16.667 35.8V34.2ZM5.86699 25C5.86699 27.3344 5.86529 29.1657 6.05718 30.593C6.25217 32.0432 6.66012 33.1956 7.56577 34.1012L8.69714 32.9698C8.13833 32.411 7.81405 31.6526 7.64292 30.3798C7.46869 29.0839 7.46699 27.3796 7.46699 25H5.86699ZM23.3337 35.8C25.6681 35.8 27.4993 35.8017 28.9266 35.6098C30.3769 35.4148 31.5292 35.0069 32.4349 34.1012L31.3035 32.9698C30.7447 33.5287 29.9863 33.8529 28.7134 34.0241C27.4175 34.1983 25.7133 34.2 23.3337 34.2V35.8ZM32.5337 25C32.5337 27.3796 32.532 29.0839 32.3577 30.3798C32.1866 31.6526 31.8623 32.411 31.3035 32.9698L32.4349 34.1012C33.3405 33.1956 33.7485 32.0432 33.9435 30.593C34.1354 29.1657 34.1337 27.3344 34.1337 25H32.5337ZM7.46699 15C7.46699 12.6204 7.46869 10.9161 7.64292 9.62024C7.81405 8.34738 8.13833 7.58897 8.69714 7.03015L7.56577 5.89878C6.66012 6.80443 6.25217 7.95676 6.05718 9.40704C5.86529 10.8343 5.86699 12.6656 5.86699 15H7.46699ZM16.667 4.2C14.3326 4.2 12.5013 4.1983 11.074 4.39019C9.62375 4.58518 8.47142 4.99313 7.56577 5.89878L8.69714 7.03015C9.25596 6.47133 10.0144 6.14706 11.2872 5.97592C12.5831 5.8017 14.2874 5.8 16.667 5.8V4.2ZM23.367 5V10H24.967V5H23.367ZM28.3337 14.9667H33.3337V13.3667H28.3337V14.9667ZM23.367 10C23.367 10.7361 23.3631 11.221 23.4464 11.6397L25.0157 11.3276C24.9709 11.1023 24.967 10.8128 24.967 10H23.367ZM28.3337 13.3667C27.5209 13.3667 27.2313 13.3628 27.0061 13.318L26.694 14.8872C27.1127 14.9705 27.5976 14.9667 28.3337 14.9667V13.3667ZM23.4464 11.6397C23.7726 13.2794 25.0543 14.5611 26.694 14.8872L27.0061 13.318C26.0011 13.1181 25.2156 12.3325 25.0157 11.3276L23.4464 11.6397ZM11.667 22.4667H25.0003V20.8667H11.667V22.4667ZM11.667 27.4667H20.0003V25.8667H11.667V27.4667ZM32.2476 10.0741L29.2539 6.70608L28.058 7.76907L31.0518 11.1371L32.2476 10.0741Z",
                                fill: "#4F46E5"
                              })
                            ])
                          ])),
                          createVNode("h2", { class: "text-center text-gray-400 text-xs leading-4" }, "XLS, XLSX or CSV, smaller than 15MB")
                        ]),
                        createVNode("div", { class: "grid gap-2" }, [
                          createVNode("h4", { class: "text-center text-gray-900 text-sm font-medium leading-snug" }, "Drag and Drop your file here or"),
                          createVNode("div", { class: "flex items-center justify-center" }, [
                            createVNode("label", null, [
                              createVNode("input", {
                                type: "file",
                                onChange: handleFile,
                                hidden: "",
                                multiple: ""
                              }, null, 32),
                              createVNode("div", { class: "flex w-28 h-9 px-2 flex-col bg-indigo-600 rounded-full shadow text-white text-xs font-semibold leading-4 items-center justify-center cursor-pointer focus:outline-none" }, "Choose File")
                            ])
                          ])
                        ])
                      ]))
                    ])
                  ])
                ]),
                _: 1
              }, 8, ["show"]),
              createVNode("div", { class: "py-12" }, [
                createVNode("div", { class: "max-w-7xl mx-auto sm:px-6 lg:px-8" }, [
                  createTextVNode(toDisplayString(_ctx.$page.props.tempUploadedFiles) + " ", 1),
                  uploadingProcess.value.progress > 0 ? (openBlock(), createBlock(_sfc_main$1, {
                    key: 0,
                    status: uploadingProcess.value.status,
                    progress: uploadingProcess.value.progress
                  }, null, 8, ["status", "progress"])) : createCommentVNode("", true),
                  createVNode("div", { class: "pb-4 w-full flex justify-between items-center" }, [
                    createVNode("p", { class: "text-gray-700 text-lg font-semibold" }, "List"),
                    createVNode("div", { class: "relative" }, [
                      createVNode("div", { class: "absolute flex items-center justify-center h-full px-2 text-gray-500 bg-gray-100 rounded-md" }, [
                        createVNode(unref(IconSearch), {
                          size: "20",
                          color: "currentColor"
                        })
                      ]),
                      withDirectives(createVNode("input", {
                        "onUpdate:modelValue": ($event) => search.value = $event,
                        class: "bg-white pl-10 text-sm w-52 shadow outline-none border-none focus:border-none focus:ring-1 focus:ring-gray-300 rounded-md",
                        placeholder: "Search..."
                      }, null, 8, ["onUpdate:modelValue"]), [
                        [vModelText, search.value]
                      ])
                    ])
                  ]),
                  createVNode("div", { class: "rounded-md shadow-sm h-full" }, [
                    createVNode("table", { class: "w-full capitalize" }, [
                      createVNode("thead", { class: "bg-white border-b-2 border-gray-100" }, [
                        createVNode("tr", null, [
                          createVNode("th", { class: "w-8 p-3 text-sm text-gray-800 font-semibold tracking-wide text-left" }, "Sl"),
                          createVNode("th", { class: "w-28 p-3 text-sm text-gray-800 font-semibold tracking-wide text-left" }, "Cell Number "),
                          createVNode("th", { class: "w-36 p-3 text-sm text-gray-800 font-semibold tracking-wide text-left" }, "Business Name "),
                          createVNode("th", { class: "w-20 p-3 text-sm text-gray-800 font-semibold tracking-wide text-left" }, "First Name "),
                          createVNode("th", { class: "w-20 p-3 text-sm text-gray-800 font-semibold tracking-wide text-left" }, "Last Name "),
                          createVNode("th", { class: "w-24 p-3 text-sm text-gray-800 font-semibold tracking-wide text-left" }, "E-Mail"),
                          createVNode("th", { class: "w-24 p-3 text-sm text-gray-800 font-semibold tracking-wide text-left" }, "Website "),
                          createVNode("th", { class: "w-24 p-3 text-sm text-gray-800 font-semibold tracking-wide text-left" }, "City"),
                          createVNode("th", { class: "w-24 p-3 text-sm text-gray-800 font-semibold tracking-wide text-left" }, "State"),
                          createVNode("th", { class: "w-24 p-3 text-sm text-gray-800 font-semibold tracking-wide text-left" }, "Business Address "),
                          createVNode("th", { class: "w-24 p-3 text-sm text-gray-800 font-semibold tracking-wide text-left" }, "Pin Code "),
                          createVNode("th", { class: "w-20 p-3 text-sm text-gray-800 font-semibold tracking-wide text-left" }, "Actions ")
                        ])
                      ]),
                      createVNode("tbody", null, [
                        (openBlock(true), createBlock(Fragment, null, renderList(_ctx.$page.props.data.data, (item, index) => {
                          return openBlock(), createBlock("tr", {
                            key: index,
                            class: [index % 2 === 1 ? "bg-white" : "bg-gray-50", "group"]
                          }, [
                            createVNode("td", { class: "p-3 text-sm text-gray-700 group-hover:text-blue-500 group-hover:underline font-bold" }, toDisplayString(getSerialNumber(index)), 1),
                            createVNode("td", { class: "p-3 text-sm text-gray-700" }, toDisplayString(item.cell_number), 1),
                            createVNode("td", { class: "p-3 text-sm text-gray-700" }, toDisplayString(item.business_name), 1),
                            createVNode("td", { class: "p-3 text-sm text-gray-700" }, toDisplayString(item.first_name), 1),
                            createVNode("td", { class: "p-3 text-sm text-gray-700" }, toDisplayString(item.last_name), 1),
                            createVNode("td", { class: "p-3 text-sm text-gray-700" }, toDisplayString(item.email), 1),
                            createVNode("td", { class: "p-3 text-sm text-gray-700" }, toDisplayString(item.website), 1),
                            createVNode("td", { class: "p-3 text-sm text-gray-700" }, toDisplayString(item.city), 1),
                            createVNode("td", { class: "p-3 text-sm text-gray-700" }, toDisplayString(item.state), 1),
                            createVNode("td", { class: "p-3 text-sm text-gray-700" }, toDisplayString(item.business_address), 1),
                            createVNode("td", { class: "p-3 text-sm text-gray-700" }, toDisplayString(item.pin_code), 1),
                            createVNode("td", { class: "p-3 text-sm text-gray-700" }, [
                              createVNode(_sfc_main$4)
                            ])
                          ], 2);
                        }), 128)),
                        search.value && !_ctx.$page.props.data.data.length ? (openBlock(), createBlock("tr", {
                          key: 0,
                          class: ["bg-white group"]
                        }, [
                          createVNode("td", {
                            class: "p-3 text-sm text-gray-700 text-center",
                            colspan: "12"
                          }, "Not found data by this `" + toDisplayString(search.value) + "` ", 1)
                        ])) : createCommentVNode("", true),
                        !search.value && !_ctx.$page.props.data.data.length ? (openBlock(), createBlock("tr", {
                          key: 1,
                          class: ["bg-white group"]
                        }, [
                          createVNode("td", {
                            class: "p-3 text-sm text-gray-700 text-center",
                            colspan: "12"
                          }, "Empty")
                        ])) : createCommentVNode("", true)
                      ])
                    ])
                  ]),
                  _ctx.$page.props.data.data.length ? (openBlock(), createBlock(_sfc_main$5, {
                    key: 1,
                    from: _ctx.$page.props.data.from,
                    to: _ctx.$page.props.data.to,
                    total: _ctx.$page.props.data.total,
                    links: _ctx.$page.props.data.links,
                    class: "mt-6"
                  }, null, 8, ["from", "to", "total", "links"])) : createCommentVNode("", true)
                ])
              ])
            ];
          }
        }),
        _: 1
      }, _parent));
    };
  }
};
const _sfc_setup = _sfc_main.setup;
_sfc_main.setup = (props, ctx) => {
  const ssrContext = useSSRContext();
  (ssrContext.modules || (ssrContext.modules = /* @__PURE__ */ new Set())).add("resources/js/Pages/Admin/DataFactory/List.vue");
  return _sfc_setup ? _sfc_setup(props, ctx) : void 0;
};
export {
  _sfc_main as default
};
