import { ref, watch, onMounted, onUnmounted, mergeProps, unref, useSSRContext, computed, mergeModels, useModel, withCtx, createTextVNode, toDisplayString, createVNode, withModifiers, createBlock, createCommentVNode, withDirectives, vModelSelect, openBlock, Fragment, renderList } from "vue";
import { ssrRenderAttrs, ssrRenderComponent, ssrRenderAttr, ssrRenderClass, ssrInterpolate, ssrIncludeBooleanAttr, ssrLooseContain, ssrRenderList, ssrLooseEqual } from "vue/server-renderer";
import { usePage, router, Head } from "@inertiajs/vue3";
import { _ as _sfc_main$5 } from "./BaseLayout-BCq0Aj0H.js";
import { IconChevronRight, IconChevronDown, IconAdjustmentsHorizontal, IconChevronLeft, IconMail, IconMapPin, IconEyeOff, IconPhone, IconWorld } from "@tabler/icons-vue";
import { L as LoadingSpinner, T as Text } from "./LoadingSpinner-DSwZvDHC.js";
import { _ as _sfc_main$7 } from "./Paginator-Ld42JZuH.js";
import { _ as _sfc_main$6 } from "./Checkbox-CXDfLSto.js";
import { debounce } from "lodash";
import { _ as _sfc_main$8 } from "./Modal-FnzSX7VA.js";
import { _ as _export_sfc } from "./_plugin-vue_export-helper-1tPrXgE0.js";
import "vue-toastification";
const _sfc_main$4 = {
  __name: "ModifierActionMenu",
  __ssrInlineRender: true,
  props: {
    state: String,
    index: Number
  },
  emits: ["onUpdateState"],
  setup(__props, { emit: __emit }) {
    const locationChecked = ref("");
    const props = __props;
    const emit = __emit;
    const open = ref(false);
    const modifierContainer = ref(null);
    const applyModifier = (state, index, actionType, action = "add") => {
      emit("onUpdateState", {
        state: props.state,
        index: props.index,
        actionType,
        action
      });
    };
    watch(locationChecked, (newV) => {
      if (newV) {
        applyModifier(props.state, props.index, "exact");
      } else {
        applyModifier(props.state, props.index, "exact", "delete");
      }
    });
    const outsideListener = (e) => {
      if (open.value && modifierContainer.value && !modifierContainer.value.contains(e.target)) {
        open.value = false;
      }
    };
    onMounted(() => {
      document.addEventListener("click", outsideListener);
    });
    onUnmounted(() => {
      document.removeEventListener("click", outsideListener);
    });
    return (_ctx, _push, _parent, _attrs) => {
      _push(`<li${ssrRenderAttrs(mergeProps({
        class: "flex gap-2 justify-start text-gray-500 py-0.5",
        ref_key: "modifierContainer",
        ref: modifierContainer
      }, _attrs))}><span>`);
      if (!open.value) {
        _push(ssrRenderComponent(unref(IconChevronRight), {
          size: "18",
          color: "currentColor"
        }, null, _parent));
      } else {
        _push(ssrRenderComponent(unref(IconChevronDown), {
          size: "18",
          color: "currentColor"
        }, null, _parent));
      }
      _push(`</span><div class="flex justify-between w-full pr-2 relative"><label class="flex cursor-pointer items-center text-sm font-medium text-gray-700 select-none dark:text-gray-400"><span class="relative"><input type="checkbox" class="sr-only"${ssrIncludeBooleanAttr(Array.isArray(locationChecked.value) ? ssrLooseContain(locationChecked.value, __props.state) : locationChecked.value) ? " checked" : ""}${ssrRenderAttr("value", __props.state)}><span class="${ssrRenderClass([locationChecked.value ? "border-brand-500 bg-brand-500" : "bg-gray-50 dark:bg-gray-800 border-gray-300 dark:border-gray-600", "hover:border-brand-500 dark:hover:border-brand-500 mr-3 flex h-5 w-5 items-center justify-center rounded-md border-[1.25px]"])}"><span class="${ssrRenderClass(locationChecked.value ? "" : "opacity-0")}"><svg width="14" height="14" viewBox="0 0 14 14" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M11.6666 3.5L5.24992 9.91667L2.33325 7" stroke="white" stroke-width="1.94437" stroke-linecap="round" stroke-linejoin="round"></path></svg></span></span></span> ${ssrInterpolate(__props.state)}</label><button class="py-1 bg-gray-50 dark:bg-gray-700 text-gray-400 px-1 rounded">`);
      _push(ssrRenderComponent(unref(IconAdjustmentsHorizontal), {
        size: "16",
        color: "currentColor"
      }, null, _parent));
      _push(`</button><div class="absolute right-[10px] top-full z-40 w-40 origin-top">`);
      if (open.value) {
        _push(`<div class="shadow md w-full bg-white dark:bg-gray-800 flex flex-col items-start rounded-md overflow-hidden"><div class="text-sm py-3 px-4 text-gray-200 dark:text-gray-200 dark:bg-brand-700 bg-blue-600 w-full">Apply Modifier</div><button class="block text-start text-gray-700 dark:hover:text-gray-800 text-sm px-4 hover:bg-gray-100 hover:text-gray-700 border-y dark:border-gray-700 border-gray-200 dark:text-gray-300 w-full py-2.5">Exact</button><button class="block text-start text-gray-700 dark:hover:text-gray-800 text-sm px-4 hover:bg-gray-100 hover:text-gray-700 border-b dark:border-gray-700 border-gray-200 dark:text-gray-300 w-full py-2.5">Exclude</button></div>`);
      } else {
        _push(`<!---->`);
      }
      _push(`</div></div></li>`);
    };
  }
};
const _sfc_setup$4 = _sfc_main$4.setup;
_sfc_main$4.setup = (props, ctx) => {
  const ssrContext = useSSRContext();
  (ssrContext.modules || (ssrContext.modules = /* @__PURE__ */ new Set())).add("resources/js/Components/Partials/ModifierActionMenu.vue");
  return _sfc_setup$4 ? _sfc_setup$4(props, ctx) : void 0;
};
const _sfc_main$3 = {
  __name: "LocationInput",
  __ssrInlineRender: true,
  props: {
    title: String,
    items: Object,
    attribute: String,
    textInputAttribute: String,
    isOpen: {
      type: Boolean,
      default: false
    }
  },
  emits: ["onUpdate"],
  setup(__props, { emit: __emit }) {
    const emit = __emit;
    const props = __props;
    const open = ref(props.isOpen);
    const locations = ref([]);
    const inputText = ref("");
    const onChange = (actionType, value) => {
      const params = {};
      value.forEach((item, index) => {
        params[`params[${index}][key]`] = item.actionType;
        params[`params[${index}][value]`] = item.state;
      });
      emit("onUpdate", {
        action: actionType,
        items: params
      });
    };
    const modifyInputData = (value) => {
      if (value.action === "add") {
        locations.value[value.index] = {
          state: value.state,
          index: value.index,
          actionType: value.actionType
        };
      }
      if (value.action === "delete") {
        const index = locations.value.findIndex((item) => (item == null ? void 0 : item.index) === value.index);
        locations.value.splice(index, 1);
      }
      onChange(props.attribute, locations.value);
    };
    const filteredItems = computed(() => {
      var _a;
      return (_a = props.items) == null ? void 0 : _a.filter((item) => {
        if (!inputText.value) return true;
        const regex = new RegExp(inputText.value, "i");
        return regex.test(item);
      });
    });
    return (_ctx, _push, _parent, _attrs) => {
      _push(`<div${ssrRenderAttrs(mergeProps({
        class: ["w-full", { "bg-gray-100 dark:bg-gray-800 rounded-md": open.value }]
      }, _attrs))}><div class="border border-gray-300 dark:border-brand-100/[0.1] rounded-md"><div class="${ssrRenderClass([[open.value ? "bg-gray-100 dark:bg-gray-700" : ""], "cursor-pointer w-full flex justify-between items-center px-4 text-gray-500"])}"><p class="py-2 font-semibold text-sm text-gray-700 dark:text-gray-300">${ssrInterpolate(__props.title)}</p>`);
      if (open.value) {
        _push(ssrRenderComponent(unref(IconChevronDown), {
          size: "16",
          color: "currentColor"
        }, null, _parent));
      } else {
        _push(ssrRenderComponent(unref(IconChevronLeft), {
          size: "16",
          color: "currentColor"
        }, null, _parent));
      }
      _push(`</div>`);
      if (open.value) {
        _push(`<div class="w-full bg-white origin-top-right dark:bg-gray-800 pt-4 pb-3 px-3 border-t border-gray-300 dark:border-gray-600"><input type="text"${ssrRenderAttr("value", inputText.value)} placeholder="Enter location ..." class="w-full text-sm bg-white dark:bg-gray-700 outline-none rounded-md border-gray-200 dark:border-gray-600 dark:placeholder-gray-400 dark:text-gray-200 text-gray-800 pl-3"><ul class="mt-4 max-h-[400px] overflow-y-auto"><!--[-->`);
        ssrRenderList(filteredItems.value, (state, index) => {
          _push(ssrRenderComponent(_sfc_main$4, {
            state,
            index,
            onOnUpdateState: modifyInputData
          }, null, _parent));
        });
        _push(`<!--]--></ul></div>`);
      } else {
        _push(`<!---->`);
      }
      _push(`</div></div>`);
    };
  }
};
const _sfc_setup$3 = _sfc_main$3.setup;
_sfc_main$3.setup = (props, ctx) => {
  const ssrContext = useSSRContext();
  (ssrContext.modules || (ssrContext.modules = /* @__PURE__ */ new Set())).add("resources/js/Components/Ui/Inputs/LocationInput.vue");
  return _sfc_setup$3 ? _sfc_setup$3(props, ctx) : void 0;
};
const _sfc_main$2 = {
  __name: "TabInput",
  __ssrInlineRender: true,
  props: /* @__PURE__ */ mergeModels({
    title: String,
    isOpen: {
      type: Boolean,
      default: false
    }
  }, {
    "modelValue": {
      required: true
    },
    "modelModifiers": {}
  }),
  emits: ["update:modelValue"],
  setup(__props) {
    const props = __props;
    const open = ref(props.isOpen || false);
    ref(null);
    const model = useModel(__props, "modelValue");
    return (_ctx, _push, _parent, _attrs) => {
      _push(`<div${ssrRenderAttrs(mergeProps({ class: "rounded-md border border-gray-300 dark:border-gray-800" }, _attrs))}><div class="${ssrRenderClass([{ "bg-gray-200 dark:bg-white/[0.2]": open.value }, "px-4 py-2.5 text-sm flex justify-between rounded-t-md"])}"><p class="dark:text-gray-300 font-semibold text-gray-700">${ssrInterpolate(__props.title)}</p><button class="text-gray-500 dark:text-gray-300">`);
      if (open.value) {
        _push(ssrRenderComponent(unref(IconChevronDown), { size: "18" }, null, _parent));
      } else {
        _push(ssrRenderComponent(unref(IconChevronLeft), { size: "18" }, null, _parent));
      }
      _push(`</button></div>`);
      if (open.value) {
        _push(`<div class="bg-white transition duration-300 rounded-b-md dark:bg-white/[0.1] px-2 py-3"><input type="text"${ssrRenderAttr("value", model.value)} placeholder="Search" class="py-2 text-sm w-full dark:placeholder:text-gray-200 outline-none border-none focus:border-none ring-1 focus:ring-brand-400 dark:ring-brand-100/[0.2] ring-brand-800/[0.2] rounded-sm dark:text-gray-200 dark:bg-gray-800"></div>`);
      } else {
        _push(`<!---->`);
      }
      _push(`</div>`);
    };
  }
};
const _sfc_setup$2 = _sfc_main$2.setup;
_sfc_main$2.setup = (props, ctx) => {
  const ssrContext = useSSRContext();
  (ssrContext.modules || (ssrContext.modules = /* @__PURE__ */ new Set())).add("resources/js/Components/Ui/Inputs/TabInput.vue");
  return _sfc_setup$2 ? _sfc_setup$2(props, ctx) : void 0;
};
const _sfc_main$1 = {
  __name: "PricingModelContent",
  __ssrInlineRender: true,
  props: ["plans", "filteredData"],
  setup(__props) {
    const props = __props;
    const formatter = new Intl.NumberFormat("en-IN", {
      style: "currency",
      currency: "INR",
      minimumFractionDigits: 2
    });
    const loading = ref(false);
    const calculateRecordPrice = (plan) => {
      const tempPrice = plan.price * props.filteredData;
      if (tempPrice < plan.limit_record) {
        console.log();
      }
      return 0;
    };
    return (_ctx, _push, _parent, _attrs) => {
      _push(`<div${ssrRenderAttrs(_attrs)}><div class="py-6 space-y-6"><p class="text-center font-semibold text-sk text-2xl dark:text-gray-400">Plans &amp; Pricing</p></div><div class="border-y border-gray-200 dark:border-gray-800 flex"><!--[-->`);
      ssrRenderList(__props.plans, (plan, index) => {
        _push(`<div class="${ssrRenderClass(["w-full relative overflow-hidden px-4 pb-4", plan.is_recommended ? "border-2 border-sky-700" : ""])}">`);
        if (plan == null ? void 0 : plan.is_recommended) {
          _push(`<div class="absolute bg-sky-600 rotate-[42deg] top-[30px] right-[-32px]"><p class="uppercase text-xs text-white px-8 py-1">Recommended</p></div>`);
        } else {
          _push(`<!---->`);
        }
        _push(`<div class="py-8"><p class="text-center text-2xl text-gray-700 dark:text-gray-200 font-bold">${ssrInterpolate(plan.name)} <sup class="capitalize">${ssrInterpolate(plan.product_line)}</sup></p></div><div class="space-y-3"><p class="font-semibold text-gray-600 dark:text-gray-200 text-center text-lg capitalize"><span class="text-yellow-600">${ssrInterpolate(plan.record_limit.toLocaleString())}</span> lookups / user</p><p class="text-gray-500 dark:text-gray-200 text-center text-xl"><span class="text-gray-700 dark:text-gray-200 text-3xl font-semibold">${ssrInterpolate(unref(formatter).format(plan.price))}</span> / Per Record</p><p class="text-gray-500 dark:text-gray-200 text-center text-xl">Billed as ${ssrInterpolate(unref(formatter).format(calculateRecordPrice(plan)))}</p><div class="py-6"><button class="w-full text-white font-bold py-2.5 bg-sky-500 hover:bg-sky-400 transition duration-300 rounded">`);
        if (loading.value) {
          _push(ssrRenderComponent(LoadingSpinner, null, null, _parent));
        } else {
          _push(`<span>Select Plan</span>`);
        }
        _push(`</button></div><div class="pb-3"><p class="font-bold dark:text-gray-200">All Plans include:</p><ul class="text-sm text-gray-500 dark:text-gray-300 pl-4"><li>Personal And Professional Emails</li><li>70 Exports per month / 840 Exports per year</li><li>Org Charts, Company Trends &amp; News</li><li>Send 500 emails per day</li><li>Zapier Integration</li></ul></div></div></div>`);
      });
      _push(`<!--]--></div></div>`);
    };
  }
};
const _sfc_setup$1 = _sfc_main$1.setup;
_sfc_main$1.setup = (props, ctx) => {
  const ssrContext = useSSRContext();
  (ssrContext.modules || (ssrContext.modules = /* @__PURE__ */ new Set())).add("resources/js/Components/Ui/Cards/PricingModelContent.vue");
  return _sfc_setup$1 ? _sfc_setup$1(props, ctx) : void 0;
};
const _sfc_main = {
  __name: "Search",
  __ssrInlineRender: true,
  setup(__props) {
    var _a;
    const props = usePage().props;
    const isOpenSelectAction = ref(false);
    const isOpenSelectActionRef = ref(null);
    const toggleIsOpenActionMenu = () => isOpenSelectAction.value = !isOpenSelectAction.value;
    const states = props.states;
    const cities = props.cities;
    props.items;
    ref(props.filters.search);
    const showGetContact = ref(false);
    const openPricingModal = ref(false);
    const toggleOpenPricingModal = () => openPricingModal.value = !openPricingModal.value;
    const selectForm = ref({
      select: "",
      items: []
    });
    const form = ref({
      name: props.filters.name,
      search: props.filters.search,
      occupation: "",
      state: "",
      states: [],
      city: "",
      cities: [],
      per_page: ((_a = props.filters) == null ? void 0 : _a.per_page) || 50
    });
    const selectAll = () => {
      selectForm.value.items = props.items.data.map((item) => item.id);
      selectForm.value.select = true;
    };
    const toggleShowGetContact = () => showGetContact.value = !showGetContact.value;
    const loading = ref(false);
    watch(form.value, debounce(async (newVal) => {
      loading.value = true;
      await router.get(route("discover.index"), form.value, {
        preserveState: true,
        replace: true,
        onFinish: function() {
          loading.value = false;
        }
      });
    }, 200));
    watch(() => selectForm.value.select, (newVal) => {
      if (newVal) {
        selectForm.value.items = usePage().props.items.data.map((item) => item.id);
      } else {
        selectForm.value.items = [];
      }
    });
    const clearSelect = () => {
      selectForm.value.select = false;
      selectForm.value.items = [];
      isOpenSelectAction.value = false;
    };
    const handleClickOutside = (e) => {
      var _a2;
      if (isOpenSelectAction.value && !((_a2 = isOpenSelectActionRef.value) == null ? void 0 : _a2.contains(e.target))) {
        isOpenSelectAction.value = false;
      }
    };
    const clearFilter = () => {
      const attributes = Object.keys(form.value);
      attributes.forEach(function(attribute) {
        form.value[attribute] = "";
      });
      router.get(route("discover.index"));
    };
    onMounted(() => {
      document.addEventListener("click", handleClickOutside);
    });
    onUnmounted(() => {
      document.removeEventListener("click", handleClickOutside);
    });
    return (_ctx, _push, _parent, _attrs) => {
      _push(`<!--[-->`);
      _push(ssrRenderComponent(unref(Head), { title: "Discover Records" }, null, _parent));
      _push(ssrRenderComponent(_sfc_main$5, null, {
        default: withCtx((_, _push2, _parent2, _scopeId) => {
          var _a2, _b, _c, _d, _e, _f, _g, _h, _i, _j, _k, _l, _m, _n, _o, _p, _q, _r;
          if (_push2) {
            _push2(`<div class="w-full flex gap-3" data-v-b3c24c67${_scopeId}><div class="w-96 rounded-md py-4 pr-4 space-y-8" data-v-b3c24c67${_scopeId}><div class="px-2 py-2 w-full rounded-full shadow-sm dark:bg-white/[0.1] bg-slate-200 flex" data-v-b3c24c67${_scopeId}><button class="bg-brand-500 text-white py-3.5 text-center w-full rounded-full text-sm font-bold" data-v-b3c24c67${_scopeId}>People</button><button class="py-3.5 text-center dark:text-gray-200 w-full rounded-full text-sm font-bold" data-v-b3c24c67${_scopeId}>Companies</button></div><div class="w-full" data-v-b3c24c67${_scopeId}><button class="dark:bg-gray-800 border-2 dark:border-gray-700 border-gray-200 w-full py-3 rounded-xl font-semibold dark:text-brand-100 text-brand-700 text-left pl-7 shadow-sm" data-v-b3c24c67${_scopeId}>Saved Searches</button></div><div class="space-y-3 pb-6 overflow-y-auto max-h-screen" data-v-b3c24c67${_scopeId}><div class="w-full flex justify-between items-center" data-v-b3c24c67${_scopeId}>`);
            _push2(ssrRenderComponent(Text, { class: "font-semibold" }, {
              default: withCtx((_2, _push3, _parent3, _scopeId2) => {
                if (_push3) {
                  _push3(`Search Filters`);
                } else {
                  return [
                    createTextVNode("Search Filters")
                  ];
                }
              }),
              _: 1
            }, _parent2, _scopeId));
            _push2(`<button class="text-brand-700 dark:text-gray-400" data-v-b3c24c67${_scopeId}>Clear All</button></div><div class="space-y-2.5" data-v-b3c24c67${_scopeId}>${ssrInterpolate((_a2 = unref(props).filters) == null ? void 0 : _a2.states)} `);
            _push2(ssrRenderComponent(_sfc_main$2, {
              isOpen: ((_c = (_b = unref(props).filters) == null ? void 0 : _b.name) == null ? void 0 : _c.length) > 0,
              title: "Name",
              modelValue: form.value.name,
              "onUpdate:modelValue": ($event) => form.value.name = $event
            }, null, _parent2, _scopeId));
            _push2(ssrRenderComponent(_sfc_main$3, {
              isOpen: ((_e = (_d = unref(props).filters) == null ? void 0 : _d.states) == null ? void 0 : _e.length) > 0,
              onOnUpdate: (data) => form.value[data.action] = data.items,
              title: "State",
              textInputAttribute: "state",
              attribute: "states",
              items: unref(states)
            }, null, _parent2, _scopeId));
            _push2(ssrRenderComponent(_sfc_main$3, {
              isOpen: ((_g = (_f = unref(props).filters) == null ? void 0 : _f.cities) == null ? void 0 : _g.length) > 0,
              onOnUpdate: (data) => form.value[data.action] = data.items,
              title: "City",
              textInputAttribute: "city",
              attribute: "cities",
              items: unref(cities)
            }, null, _parent2, _scopeId));
            _push2(ssrRenderComponent(_sfc_main$2, {
              isOpen: ((_i = (_h = unref(props).filters) == null ? void 0 : _h.name) == null ? void 0 : _i.length) > 0,
              title: "Occupation",
              modelValue: form.value.occupation,
              "onUpdate:modelValue": ($event) => form.value.occupation = $event
            }, null, _parent2, _scopeId));
            _push2(`</div></div></div><div class="flex-1 rounded-md shadow-md px-4 py-5 box-border dark:bg-white/[0.03] bg-gray-100" data-v-b3c24c67${_scopeId}><div class="w-full flex justify-between items-center" data-v-b3c24c67${_scopeId}><p class="text-sm text-gray-600 dark:text-gray-200" data-v-b3c24c67${_scopeId}>Showing ${ssrInterpolate(_ctx.$page.props.items.from)} to ${ssrInterpolate(_ctx.$page.props.items.to)} of ${ssrInterpolate(_ctx.$page.props.items.total)} results</p><div data-v-b3c24c67${_scopeId}><select name="per_page" id="per_page" class="dark:bg-gray-700 bg-gray-100 border-gray-300 dark:border-gray-500 text-gray-700 dark:text-gray-100 w-36 text-sm rounded-md" data-v-b3c24c67${_scopeId}><option value="50" data-v-b3c24c67${ssrIncludeBooleanAttr(Array.isArray(form.value.per_page) ? ssrLooseContain(form.value.per_page, "50") : ssrLooseEqual(form.value.per_page, "50")) ? " selected" : ""}${_scopeId}>50</option><option value="100" data-v-b3c24c67${ssrIncludeBooleanAttr(Array.isArray(form.value.per_page) ? ssrLooseContain(form.value.per_page, "100") : ssrLooseEqual(form.value.per_page, "100")) ? " selected" : ""}${_scopeId}>100</option><option value="250" data-v-b3c24c67${ssrIncludeBooleanAttr(Array.isArray(form.value.per_page) ? ssrLooseContain(form.value.per_page, "250") : ssrLooseEqual(form.value.per_page, "250")) ? " selected" : ""}${_scopeId}>250</option><option value="500" data-v-b3c24c67${ssrIncludeBooleanAttr(Array.isArray(form.value.per_page) ? ssrLooseContain(form.value.per_page, "500") : ssrLooseEqual(form.value.per_page, "500")) ? " selected" : ""}${_scopeId}>500</option><option value="750" data-v-b3c24c67${ssrIncludeBooleanAttr(Array.isArray(form.value.per_page) ? ssrLooseContain(form.value.per_page, "750") : ssrLooseEqual(form.value.per_page, "750")) ? " selected" : ""}${_scopeId}>750</option><option value="1000" data-v-b3c24c67${ssrIncludeBooleanAttr(Array.isArray(form.value.per_page) ? ssrLooseContain(form.value.per_page, "1000") : ssrLooseEqual(form.value.per_page, "1000")) ? " selected" : ""}${_scopeId}>1000</option></select></div></div><div class="flex justify-between flex-col py-5" data-v-b3c24c67${_scopeId}>`);
            if (selectForm.value.items.length) {
              _push2(`<div class="relative flex items-center gap-4 pb-4" data-v-b3c24c67${_scopeId}>`);
              if (selectForm.value.items.length) {
                _push2(`<p class="text-sm dark:text-gray-100 text-gray-600" data-v-b3c24c67${_scopeId}>${ssrInterpolate(selectForm.value.items.length)} Selected</p>`);
              } else {
                _push2(`<!---->`);
              }
              if (selectForm.value.items.length) {
                _push2(`<button class="py-1.5 px-3.5 dark:bg-brand-500 bg-brand-500 hover:bg-brand-400 active:bg-brand-600 transition duration-300 text-xs text-gray-100 rounded-md" data-v-b3c24c67${_scopeId}>Get Contacts</button>`);
              } else {
                _push2(`<!---->`);
              }
              if (selectForm.value.items.length) {
                _push2(`<button class="py-1.5 px-3 text-sm dark:text-gray-100 text-gray-600 rounded-md flex gap-1.5 items-center hover:bg-gray-200 dark:hover:bg-gray-600 transition duration-300" data-v-b3c24c67${_scopeId}>`);
                _push2(ssrRenderComponent(unref(IconMail), {
                  size: "20",
                  color: "currentColor"
                }, null, _parent2, _scopeId));
                _push2(`<span data-v-b3c24c67${_scopeId}>Email Contacts</span></button>`);
              } else {
                _push2(`<!---->`);
              }
              _push2(`<div class="absolute w-48 left-[40px] top-[40px] z-40" data-v-b3c24c67${_scopeId}><div class="${ssrRenderClass([[isOpenSelectAction.value ? "block" : "hidden"], "bg-white dark:bg-gray-700 shadow-sm border-gray-300 rounded-md overflow-hidden"])}" data-v-b3c24c67${_scopeId}><button class="text-sm text-start dark:hover:bg-gray-600 dark:text-gray-100 text-gray-600 font-semibold w-full py-4 px-4" data-v-b3c24c67${_scopeId}>Select Page (${ssrInterpolate(_ctx.$page.props.items.per_page)})</button><button class="text-sm text-start dark:hover:bg-gray-600 dark:text-gray-100 text-gray-600 font-semibold w-full py-4 px-4" data-v-b3c24c67${_scopeId}>Clear All</button></div></div></div>`);
            } else {
              _push2(`<!---->`);
            }
            _push2(`<table class="min-w-full text-sm text-left text-gray-500 dark:text-gray-400" data-v-b3c24c67${_scopeId}><thead data-v-b3c24c67${_scopeId}><tr data-v-b3c24c67${_scopeId}><th class="font-bold py-2 text-start dark:bg-white/[0.05] bg-gray-200 dark:text-gray-100 text-gray-600 pl-4 w-56" data-v-b3c24c67${_scopeId}><div class="flex gap-2 items-center" data-v-b3c24c67${_scopeId}><div class="flex items-center justify-center gap-1 py-2 rounded-full" data-v-b3c24c67${_scopeId}>`);
            _push2(ssrRenderComponent(_sfc_main$6, {
              modelValue: selectForm.value.select,
              "onUpdate:modelValue": ($event) => selectForm.value.select = $event,
              "for-id": "select-all"
            }, null, _parent2, _scopeId));
            _push2(`<button class="dark:text-gray-300" data-v-b3c24c67${_scopeId}>`);
            _push2(ssrRenderComponent(unref(IconChevronDown), { size: "20" }, null, _parent2, _scopeId));
            _push2(`</button></div><span data-v-b3c24c67${_scopeId}>Name</span></div></th><th class="font-bold py-2 text-start dark:bg-white/[0.05] bg-gray-200 dark:text-gray-100 text-gray-600 w-64" data-v-b3c24c67${_scopeId}>Business</th><th class="font-bold py-2 text-start dark:bg-white/[0.05] bg-gray-200 dark:text-gray-100 text-gray-600 w-64" data-v-b3c24c67${_scopeId}>Contact Info</th><th class="font-bold py-2 text-start dark:bg-white/[0.05] bg-gray-200 dark:text-gray-100 text-gray-600 w-28" data-v-b3c24c67${_scopeId}>Actions</th></tr></thead><tbody data-v-b3c24c67${_scopeId}>`);
            if (loading.value) {
              _push2(`<!--[-->`);
              ssrRenderList(15, (i) => {
                _push2(`<tr data-v-b3c24c67${_scopeId}><td class="px-4 py-5 w-56" data-v-b3c24c67${_scopeId}><div class="flex gap-3 items-center" data-v-b3c24c67${_scopeId}><div class="w-12 h-12 rounded-full skeleton" data-v-b3c24c67${_scopeId}></div><div class="flex-1 space-y-2" data-v-b3c24c67${_scopeId}><div class="h-4 w-1/2 rounded skeleton" data-v-b3c24c67${_scopeId}></div><div class="h-3 w-1/3 rounded skeleton" data-v-b3c24c67${_scopeId}></div></div></div></td><td class="py-5 w-64 space-y-2" data-v-b3c24c67${_scopeId}><div class="h-4 w-2/3 rounded skeleton" data-v-b3c24c67${_scopeId}></div><div class="h-3 w-1/2 rounded skeleton" data-v-b3c24c67${_scopeId}></div></td><td class="py-5 w-64 space-y-2" data-v-b3c24c67${_scopeId}><div class="h-3 w-2/3 rounded skeleton" data-v-b3c24c67${_scopeId}></div><div class="h-3 w-1/2 rounded skeleton" data-v-b3c24c67${_scopeId}></div><div class="h-3 w-1/4 rounded skeleton" data-v-b3c24c67${_scopeId}></div></td><td class="py-5 w-28 text-center space-y-2" data-v-b3c24c67${_scopeId}><div class="h-8 w-24 mx-auto rounded skeleton" data-v-b3c24c67${_scopeId}></div><div class="h-4 w-20 mx-auto rounded skeleton" data-v-b3c24c67${_scopeId}></div></td></tr>`);
              });
              _push2(`<!--]-->`);
            } else {
              _push2(`<!--[-->`);
              ssrRenderList(_ctx.$page.props.items.data, (item, index) => {
                _push2(`<tr class="even:bg-gray-50 dark:even:bg-gray-800 hover:bg-gray-100 dark:hover:bg-gray-700" data-v-b3c24c67${_scopeId}><td class="px-4 py-4 w-56" data-v-b3c24c67${_scopeId}><div class="flex gap-3 items-center" data-v-b3c24c67${_scopeId}>`);
                _push2(ssrRenderComponent(_sfc_main$6, {
                  modelValue: selectForm.value.items[index],
                  "onUpdate:modelValue": ($event) => selectForm.value.items[index] = $event,
                  value: item.id
                }, null, _parent2, _scopeId));
                _push2(`<img src="https://i.pravatar.cc/300"${ssrRenderAttr("alt", item == null ? void 0 : item.first_name)} class="w-12 h-12 rounded-full shadow-md border-gray-300" data-v-b3c24c67${_scopeId}><div data-v-b3c24c67${_scopeId}>`);
                _push2(ssrRenderComponent(Text, { class: "font-semibold dark:text-gray-200 text-gray-700" }, {
                  default: withCtx((_2, _push3, _parent3, _scopeId2) => {
                    if (_push3) {
                      _push3(`${ssrInterpolate(item == null ? void 0 : item.first_name)} ${ssrInterpolate(item == null ? void 0 : item.last_name)}`);
                    } else {
                      return [
                        createTextVNode(toDisplayString(item == null ? void 0 : item.first_name) + " " + toDisplayString(item == null ? void 0 : item.last_name), 1)
                      ];
                    }
                  }),
                  _: 2
                }, _parent2, _scopeId));
                _push2(ssrRenderComponent(Text, { class: "flex text-sm items-center gap-1 dark:text-gray-400 text-gray-600" }, {
                  default: withCtx((_2, _push3, _parent3, _scopeId2) => {
                    if (_push3) {
                      _push3(ssrRenderComponent(unref(IconMapPin), { size: "16" }, null, _parent3, _scopeId2));
                      _push3(` ${ssrInterpolate(`${item.city}, ${item.state}`)}`);
                    } else {
                      return [
                        createVNode(unref(IconMapPin), { size: "16" }),
                        createTextVNode(" " + toDisplayString(`${item.city}, ${item.state}`), 1)
                      ];
                    }
                  }),
                  _: 2
                }, _parent2, _scopeId));
                _push2(`</div></div></td><td class="py-4 w-64" data-v-b3c24c67${_scopeId}>`);
                _push2(ssrRenderComponent(Text, { class: "font-bold dark:text-gray-200 text-gray-700" }, {
                  default: withCtx((_2, _push3, _parent3, _scopeId2) => {
                    if (_push3) {
                      _push3(`${ssrInterpolate(item.business_name)}`);
                    } else {
                      return [
                        createTextVNode(toDisplayString(item.business_name), 1)
                      ];
                    }
                  }),
                  _: 2
                }, _parent2, _scopeId));
                _push2(ssrRenderComponent(Text, { class: "text-sm flex items-center gap-1" }, {
                  default: withCtx((_2, _push3, _parent3, _scopeId2) => {
                    if (_push3) {
                      _push3(ssrRenderComponent(unref(IconMapPin), { size: "16" }, null, _parent3, _scopeId2));
                      _push3(` ${ssrInterpolate(item.business_address)}`);
                    } else {
                      return [
                        createVNode(unref(IconMapPin), { size: "16" }),
                        createTextVNode(" " + toDisplayString(item.business_address), 1)
                      ];
                    }
                  }),
                  _: 2
                }, _parent2, _scopeId));
                _push2(`</td><td class="py-4 w-64 relative group" data-v-b3c24c67${_scopeId}><div class="group-hover:block hidden absolute top-0 z-10 justify-center items-center pt-10" data-v-b3c24c67${_scopeId}><button class="px-4 bg-gray-800 py-1.5 rounded-md text-white flex gap-1 text-xs items-center" data-v-b3c24c67${_scopeId}>`);
                _push2(ssrRenderComponent(unref(IconEyeOff), { size: "20" }, null, _parent2, _scopeId));
                _push2(`<span data-v-b3c24c67${_scopeId}>Get Contact</span></button></div><div class="blur-sm space-y-1 text-sm" data-v-b3c24c67${_scopeId}>`);
                _push2(ssrRenderComponent(Text, { class: "flex items-center gap-1.5" }, {
                  default: withCtx((_2, _push3, _parent3, _scopeId2) => {
                    if (_push3) {
                      _push3(ssrRenderComponent(unref(IconMail), { size: "20" }, null, _parent3, _scopeId2));
                      _push3(` ${ssrInterpolate(item.email)}`);
                    } else {
                      return [
                        createVNode(unref(IconMail), { size: "20" }),
                        createTextVNode(" " + toDisplayString(item.email), 1)
                      ];
                    }
                  }),
                  _: 2
                }, _parent2, _scopeId));
                _push2(ssrRenderComponent(Text, { class: "flex items-center gap-1.5" }, {
                  default: withCtx((_2, _push3, _parent3, _scopeId2) => {
                    if (_push3) {
                      _push3(ssrRenderComponent(unref(IconPhone), { size: "20" }, null, _parent3, _scopeId2));
                      _push3(` ${ssrInterpolate(item.cell_number)}`);
                    } else {
                      return [
                        createVNode(unref(IconPhone), { size: "20" }),
                        createTextVNode(" " + toDisplayString(item.cell_number), 1)
                      ];
                    }
                  }),
                  _: 2
                }, _parent2, _scopeId));
                if (item.website) {
                  _push2(ssrRenderComponent(Text, { class: "flex items-center gap-1.5" }, {
                    default: withCtx((_2, _push3, _parent3, _scopeId2) => {
                      if (_push3) {
                        _push3(ssrRenderComponent(unref(IconWorld), { size: "20" }, null, _parent3, _scopeId2));
                        _push3(` ${ssrInterpolate(item.website)}`);
                      } else {
                        return [
                          createVNode(unref(IconWorld), { size: "20" }),
                          createTextVNode(" " + toDisplayString(item.website), 1)
                        ];
                      }
                    }),
                    _: 2
                  }, _parent2, _scopeId));
                } else {
                  _push2(`<!---->`);
                }
                _push2(`</div></td><td class="py-4 w-28 text-center space-y-2" data-v-b3c24c67${_scopeId}><button class="block dark:bg-brand-500 bg-brand-400 hover:bg-brand-500 px-3 py-2.5 text-xs text-white font-bold rounded-md" data-v-b3c24c67${_scopeId}>Get Contact Info</button><button class="text-sm dark:text-brand-200 text-brand-700 py-1 block" data-v-b3c24c67${_scopeId}>View More</button></td></tr>`);
              });
              _push2(`<!--]-->`);
            }
            _push2(`</tbody></table></div>`);
            if (_ctx.$page.props.items.data.length) {
              _push2(ssrRenderComponent(_sfc_main$7, {
                hidePageInfo: true,
                "active-bg": "bg-gray-700",
                from: _ctx.$page.props.items.from,
                to: _ctx.$page.props.items.to,
                total: _ctx.$page.props.items.total,
                links: _ctx.$page.props.items.links,
                class: "pt-3"
              }, null, _parent2, _scopeId));
            } else {
              _push2(`<!---->`);
            }
            _push2(`</div></div>`);
            _push2(ssrRenderComponent(_sfc_main$8, { show: showGetContact.value }, {
              default: withCtx((_2, _push3, _parent3, _scopeId2) => {
                if (_push3) {
                  _push3(`<div class="w-full bg-white dark:bg-gray-700 px-4 py-4 space-y-4" data-v-b3c24c67${_scopeId2}><p class="text-brand-800 dark:text-brand-50 text-xl font-bold w-full" data-v-b3c24c67${_scopeId2}>Get Contact Info for Selected Contacts</p><p class="text-sm text-brand-950 dark:text-brand-50" data-v-b3c24c67${_scopeId2}>You have selected <span class="font-bold" data-v-b3c24c67${_scopeId2}>${ssrInterpolate(selectForm.value.items.length)} contacts</span> for lookup. <span class="font-bold" data-v-b3c24c67${_scopeId2}>9 contacts</span> haven&#39;t been previously looked up so this will use up to 9 credits. Continue?</p><div class="w-full flex justify-end items-center gap-3" data-v-b3c24c67${_scopeId2}><button class="font-normal px-5 py-1.5 rounded-md bg-brand-500 hover:bg-brand-600 border border-brand-500 hover:border-brand-600 text-white" data-v-b3c24c67${_scopeId2}>Ok</button><button class="dark:text-gray-200 text-gray-600 font-medium px-5 py-1.5 rounded-md bg-white dark:bg-white/[0.2] hover:bg-gray-100 border border-gray-400 dark:border-gray-700 hover:border-gray-600" data-v-b3c24c67${_scopeId2}>Cancel</button></div></div>`);
                } else {
                  return [
                    createVNode("div", { class: "w-full bg-white dark:bg-gray-700 px-4 py-4 space-y-4" }, [
                      createVNode("p", { class: "text-brand-800 dark:text-brand-50 text-xl font-bold w-full" }, "Get Contact Info for Selected Contacts"),
                      createVNode("p", { class: "text-sm text-brand-950 dark:text-brand-50" }, [
                        createTextVNode("You have selected "),
                        createVNode("span", { class: "font-bold" }, toDisplayString(selectForm.value.items.length) + " contacts", 1),
                        createTextVNode(" for lookup. "),
                        createVNode("span", { class: "font-bold" }, "9 contacts"),
                        createTextVNode(" haven't been previously looked up so this will use up to 9 credits. Continue?")
                      ]),
                      createVNode("div", { class: "w-full flex justify-end items-center gap-3" }, [
                        createVNode("button", { class: "font-normal px-5 py-1.5 rounded-md bg-brand-500 hover:bg-brand-600 border border-brand-500 hover:border-brand-600 text-white" }, "Ok"),
                        createVNode("button", {
                          onClick: withModifiers(toggleShowGetContact, ["prevent"]),
                          class: "dark:text-gray-200 text-gray-600 font-medium px-5 py-1.5 rounded-md bg-white dark:bg-white/[0.2] hover:bg-gray-100 border border-gray-400 dark:border-gray-700 hover:border-gray-600"
                        }, "Cancel")
                      ])
                    ])
                  ];
                }
              }),
              _: 1
            }, _parent2, _scopeId));
            _push2(ssrRenderComponent(_sfc_main$8, {
              show: openPricingModal.value,
              onClose: toggleOpenPricingModal,
              closeable: true,
              "max-width": `${unref(props).plans.length > 1 ? "1/2" : "lg"}`
            }, {
              default: withCtx((_2, _push3, _parent3, _scopeId2) => {
                if (_push3) {
                  _push3(ssrRenderComponent(_sfc_main$1, {
                    plans: _ctx.$page.props.plans,
                    "filtered-data": _ctx.$page.props.items.total
                  }, null, _parent3, _scopeId2));
                } else {
                  return [
                    createVNode(_sfc_main$1, {
                      plans: _ctx.$page.props.plans,
                      "filtered-data": _ctx.$page.props.items.total
                    }, null, 8, ["plans", "filtered-data"])
                  ];
                }
              }),
              _: 1
            }, _parent2, _scopeId));
          } else {
            return [
              createVNode("div", { class: "w-full flex gap-3" }, [
                createVNode("div", { class: "w-96 rounded-md py-4 pr-4 space-y-8" }, [
                  createVNode("div", { class: "px-2 py-2 w-full rounded-full shadow-sm dark:bg-white/[0.1] bg-slate-200 flex" }, [
                    createVNode("button", { class: "bg-brand-500 text-white py-3.5 text-center w-full rounded-full text-sm font-bold" }, "People"),
                    createVNode("button", { class: "py-3.5 text-center dark:text-gray-200 w-full rounded-full text-sm font-bold" }, "Companies")
                  ]),
                  createVNode("div", { class: "w-full" }, [
                    createVNode("button", { class: "dark:bg-gray-800 border-2 dark:border-gray-700 border-gray-200 w-full py-3 rounded-xl font-semibold dark:text-brand-100 text-brand-700 text-left pl-7 shadow-sm" }, "Saved Searches")
                  ]),
                  createVNode("div", { class: "space-y-3 pb-6 overflow-y-auto max-h-screen" }, [
                    createVNode("div", { class: "w-full flex justify-between items-center" }, [
                      createVNode(Text, { class: "font-semibold" }, {
                        default: withCtx(() => [
                          createTextVNode("Search Filters")
                        ]),
                        _: 1
                      }),
                      createVNode("button", {
                        class: "text-brand-700 dark:text-gray-400",
                        onClick: clearFilter
                      }, "Clear All")
                    ]),
                    createVNode("div", { class: "space-y-2.5" }, [
                      createTextVNode(toDisplayString((_j = unref(props).filters) == null ? void 0 : _j.states) + " ", 1),
                      createVNode(_sfc_main$2, {
                        isOpen: ((_l = (_k = unref(props).filters) == null ? void 0 : _k.name) == null ? void 0 : _l.length) > 0,
                        title: "Name",
                        modelValue: form.value.name,
                        "onUpdate:modelValue": ($event) => form.value.name = $event
                      }, null, 8, ["isOpen", "modelValue", "onUpdate:modelValue"]),
                      createVNode(_sfc_main$3, {
                        isOpen: ((_n = (_m = unref(props).filters) == null ? void 0 : _m.states) == null ? void 0 : _n.length) > 0,
                        onOnUpdate: (data) => form.value[data.action] = data.items,
                        title: "State",
                        textInputAttribute: "state",
                        attribute: "states",
                        items: unref(states)
                      }, null, 8, ["isOpen", "onOnUpdate", "items"]),
                      createVNode(_sfc_main$3, {
                        isOpen: ((_p = (_o = unref(props).filters) == null ? void 0 : _o.cities) == null ? void 0 : _p.length) > 0,
                        onOnUpdate: (data) => form.value[data.action] = data.items,
                        title: "City",
                        textInputAttribute: "city",
                        attribute: "cities",
                        items: unref(cities)
                      }, null, 8, ["isOpen", "onOnUpdate", "items"]),
                      createVNode(_sfc_main$2, {
                        isOpen: ((_r = (_q = unref(props).filters) == null ? void 0 : _q.name) == null ? void 0 : _r.length) > 0,
                        title: "Occupation",
                        modelValue: form.value.occupation,
                        "onUpdate:modelValue": ($event) => form.value.occupation = $event
                      }, null, 8, ["isOpen", "modelValue", "onUpdate:modelValue"])
                    ])
                  ])
                ]),
                createVNode("div", { class: "flex-1 rounded-md shadow-md px-4 py-5 box-border dark:bg-white/[0.03] bg-gray-100" }, [
                  createVNode("div", { class: "w-full flex justify-between items-center" }, [
                    createVNode("p", { class: "text-sm text-gray-600 dark:text-gray-200" }, "Showing " + toDisplayString(_ctx.$page.props.items.from) + " to " + toDisplayString(_ctx.$page.props.items.to) + " of " + toDisplayString(_ctx.$page.props.items.total) + " results", 1),
                    createVNode("div", null, [
                      withDirectives(createVNode("select", {
                        "onUpdate:modelValue": ($event) => form.value.per_page = $event,
                        name: "per_page",
                        id: "per_page",
                        class: "dark:bg-gray-700 bg-gray-100 border-gray-300 dark:border-gray-500 text-gray-700 dark:text-gray-100 w-36 text-sm rounded-md"
                      }, [
                        createVNode("option", { value: "50" }, "50"),
                        createVNode("option", { value: "100" }, "100"),
                        createVNode("option", { value: "250" }, "250"),
                        createVNode("option", { value: "500" }, "500"),
                        createVNode("option", { value: "750" }, "750"),
                        createVNode("option", { value: "1000" }, "1000")
                      ], 8, ["onUpdate:modelValue"]), [
                        [vModelSelect, form.value.per_page]
                      ])
                    ])
                  ]),
                  createVNode("div", {
                    ref_key: "isOpenSelectActionRef",
                    ref: isOpenSelectActionRef,
                    class: "flex justify-between flex-col py-5"
                  }, [
                    selectForm.value.items.length ? (openBlock(), createBlock("div", {
                      key: 0,
                      class: "relative flex items-center gap-4 pb-4"
                    }, [
                      selectForm.value.items.length ? (openBlock(), createBlock("p", {
                        key: 0,
                        class: "text-sm dark:text-gray-100 text-gray-600"
                      }, toDisplayString(selectForm.value.items.length) + " Selected", 1)) : createCommentVNode("", true),
                      selectForm.value.items.length ? (openBlock(), createBlock("button", {
                        key: 1,
                        class: "py-1.5 px-3.5 dark:bg-brand-500 bg-brand-500 hover:bg-brand-400 active:bg-brand-600 transition duration-300 text-xs text-gray-100 rounded-md",
                        onClick: toggleShowGetContact
                      }, "Get Contacts")) : createCommentVNode("", true),
                      selectForm.value.items.length ? (openBlock(), createBlock("button", {
                        key: 2,
                        class: "py-1.5 px-3 text-sm dark:text-gray-100 text-gray-600 rounded-md flex gap-1.5 items-center hover:bg-gray-200 dark:hover:bg-gray-600 transition duration-300"
                      }, [
                        createVNode(unref(IconMail), {
                          size: "20",
                          color: "currentColor"
                        }),
                        createVNode("span", null, "Email Contacts")
                      ])) : createCommentVNode("", true),
                      createVNode("div", { class: "absolute w-48 left-[40px] top-[40px] z-40" }, [
                        createVNode("div", {
                          class: [[isOpenSelectAction.value ? "block" : "hidden"], "bg-white dark:bg-gray-700 shadow-sm border-gray-300 rounded-md overflow-hidden"]
                        }, [
                          createVNode("button", {
                            class: "text-sm text-start dark:hover:bg-gray-600 dark:text-gray-100 text-gray-600 font-semibold w-full py-4 px-4",
                            onClick: selectAll
                          }, "Select Page (" + toDisplayString(_ctx.$page.props.items.per_page) + ")", 1),
                          createVNode("button", {
                            class: "text-sm text-start dark:hover:bg-gray-600 dark:text-gray-100 text-gray-600 font-semibold w-full py-4 px-4",
                            onClick: clearSelect
                          }, "Clear All")
                        ], 2)
                      ])
                    ])) : createCommentVNode("", true),
                    createVNode("table", { class: "min-w-full text-sm text-left text-gray-500 dark:text-gray-400" }, [
                      createVNode("thead", null, [
                        createVNode("tr", null, [
                          createVNode("th", { class: "font-bold py-2 text-start dark:bg-white/[0.05] bg-gray-200 dark:text-gray-100 text-gray-600 pl-4 w-56" }, [
                            createVNode("div", { class: "flex gap-2 items-center" }, [
                              createVNode("div", { class: "flex items-center justify-center gap-1 py-2 rounded-full" }, [
                                createVNode(_sfc_main$6, {
                                  modelValue: selectForm.value.select,
                                  "onUpdate:modelValue": ($event) => selectForm.value.select = $event,
                                  "for-id": "select-all"
                                }, null, 8, ["modelValue", "onUpdate:modelValue"]),
                                createVNode("button", {
                                  onClick: toggleIsOpenActionMenu,
                                  class: "dark:text-gray-300"
                                }, [
                                  createVNode(unref(IconChevronDown), { size: "20" })
                                ])
                              ]),
                              createVNode("span", null, "Name")
                            ])
                          ]),
                          createVNode("th", { class: "font-bold py-2 text-start dark:bg-white/[0.05] bg-gray-200 dark:text-gray-100 text-gray-600 w-64" }, "Business"),
                          createVNode("th", { class: "font-bold py-2 text-start dark:bg-white/[0.05] bg-gray-200 dark:text-gray-100 text-gray-600 w-64" }, "Contact Info"),
                          createVNode("th", { class: "font-bold py-2 text-start dark:bg-white/[0.05] bg-gray-200 dark:text-gray-100 text-gray-600 w-28" }, "Actions")
                        ])
                      ]),
                      createVNode("tbody", null, [
                        loading.value ? (openBlock(), createBlock(Fragment, { key: 0 }, renderList(15, (i) => {
                          return createVNode("tr", {
                            key: `skeleton-${i}`
                          }, [
                            createVNode("td", { class: "px-4 py-5 w-56" }, [
                              createVNode("div", { class: "flex gap-3 items-center" }, [
                                createVNode("div", { class: "w-12 h-12 rounded-full skeleton" }),
                                createVNode("div", { class: "flex-1 space-y-2" }, [
                                  createVNode("div", { class: "h-4 w-1/2 rounded skeleton" }),
                                  createVNode("div", { class: "h-3 w-1/3 rounded skeleton" })
                                ])
                              ])
                            ]),
                            createVNode("td", { class: "py-5 w-64 space-y-2" }, [
                              createVNode("div", { class: "h-4 w-2/3 rounded skeleton" }),
                              createVNode("div", { class: "h-3 w-1/2 rounded skeleton" })
                            ]),
                            createVNode("td", { class: "py-5 w-64 space-y-2" }, [
                              createVNode("div", { class: "h-3 w-2/3 rounded skeleton" }),
                              createVNode("div", { class: "h-3 w-1/2 rounded skeleton" }),
                              createVNode("div", { class: "h-3 w-1/4 rounded skeleton" })
                            ]),
                            createVNode("td", { class: "py-5 w-28 text-center space-y-2" }, [
                              createVNode("div", { class: "h-8 w-24 mx-auto rounded skeleton" }),
                              createVNode("div", { class: "h-4 w-20 mx-auto rounded skeleton" })
                            ])
                          ]);
                        }), 64)) : (openBlock(true), createBlock(Fragment, { key: 1 }, renderList(_ctx.$page.props.items.data, (item, index) => {
                          return openBlock(), createBlock("tr", {
                            key: `item-${item.id}`,
                            class: "even:bg-gray-50 dark:even:bg-gray-800 hover:bg-gray-100 dark:hover:bg-gray-700"
                          }, [
                            createVNode("td", { class: "px-4 py-4 w-56" }, [
                              createVNode("div", { class: "flex gap-3 items-center" }, [
                                createVNode(_sfc_main$6, {
                                  modelValue: selectForm.value.items[index],
                                  "onUpdate:modelValue": ($event) => selectForm.value.items[index] = $event,
                                  value: item.id
                                }, null, 8, ["modelValue", "onUpdate:modelValue", "value"]),
                                createVNode("img", {
                                  src: "https://i.pravatar.cc/300",
                                  alt: item == null ? void 0 : item.first_name,
                                  class: "w-12 h-12 rounded-full shadow-md border-gray-300"
                                }, null, 8, ["alt"]),
                                createVNode("div", null, [
                                  createVNode(Text, { class: "font-semibold dark:text-gray-200 text-gray-700" }, {
                                    default: withCtx(() => [
                                      createTextVNode(toDisplayString(item == null ? void 0 : item.first_name) + " " + toDisplayString(item == null ? void 0 : item.last_name), 1)
                                    ]),
                                    _: 2
                                  }, 1024),
                                  createVNode(Text, { class: "flex text-sm items-center gap-1 dark:text-gray-400 text-gray-600" }, {
                                    default: withCtx(() => [
                                      createVNode(unref(IconMapPin), { size: "16" }),
                                      createTextVNode(" " + toDisplayString(`${item.city}, ${item.state}`), 1)
                                    ]),
                                    _: 2
                                  }, 1024)
                                ])
                              ])
                            ]),
                            createVNode("td", { class: "py-4 w-64" }, [
                              createVNode(Text, { class: "font-bold dark:text-gray-200 text-gray-700" }, {
                                default: withCtx(() => [
                                  createTextVNode(toDisplayString(item.business_name), 1)
                                ]),
                                _: 2
                              }, 1024),
                              createVNode(Text, { class: "text-sm flex items-center gap-1" }, {
                                default: withCtx(() => [
                                  createVNode(unref(IconMapPin), { size: "16" }),
                                  createTextVNode(" " + toDisplayString(item.business_address), 1)
                                ]),
                                _: 2
                              }, 1024)
                            ]),
                            createVNode("td", { class: "py-4 w-64 relative group" }, [
                              createVNode("div", { class: "group-hover:block hidden absolute top-0 z-10 justify-center items-center pt-10" }, [
                                createVNode("button", { class: "px-4 bg-gray-800 py-1.5 rounded-md text-white flex gap-1 text-xs items-center" }, [
                                  createVNode(unref(IconEyeOff), { size: "20" }),
                                  createVNode("span", null, "Get Contact")
                                ])
                              ]),
                              createVNode("div", { class: "blur-sm space-y-1 text-sm" }, [
                                createVNode(Text, { class: "flex items-center gap-1.5" }, {
                                  default: withCtx(() => [
                                    createVNode(unref(IconMail), { size: "20" }),
                                    createTextVNode(" " + toDisplayString(item.email), 1)
                                  ]),
                                  _: 2
                                }, 1024),
                                createVNode(Text, { class: "flex items-center gap-1.5" }, {
                                  default: withCtx(() => [
                                    createVNode(unref(IconPhone), { size: "20" }),
                                    createTextVNode(" " + toDisplayString(item.cell_number), 1)
                                  ]),
                                  _: 2
                                }, 1024),
                                item.website ? (openBlock(), createBlock(Text, {
                                  key: 0,
                                  class: "flex items-center gap-1.5"
                                }, {
                                  default: withCtx(() => [
                                    createVNode(unref(IconWorld), { size: "20" }),
                                    createTextVNode(" " + toDisplayString(item.website), 1)
                                  ]),
                                  _: 2
                                }, 1024)) : createCommentVNode("", true)
                              ])
                            ]),
                            createVNode("td", { class: "py-4 w-28 text-center space-y-2" }, [
                              createVNode("button", {
                                onClick: toggleOpenPricingModal,
                                class: "block dark:bg-brand-500 bg-brand-400 hover:bg-brand-500 px-3 py-2.5 text-xs text-white font-bold rounded-md"
                              }, "Get Contact Info"),
                              createVNode("button", { class: "text-sm dark:text-brand-200 text-brand-700 py-1 block" }, "View More")
                            ])
                          ]);
                        }), 128))
                      ])
                    ])
                  ], 512),
                  _ctx.$page.props.items.data.length ? (openBlock(), createBlock(_sfc_main$7, {
                    key: 0,
                    hidePageInfo: true,
                    "active-bg": "bg-gray-700",
                    from: _ctx.$page.props.items.from,
                    to: _ctx.$page.props.items.to,
                    total: _ctx.$page.props.items.total,
                    links: _ctx.$page.props.items.links,
                    class: "pt-3"
                  }, null, 8, ["from", "to", "total", "links"])) : createCommentVNode("", true)
                ])
              ]),
              createVNode(_sfc_main$8, { show: showGetContact.value }, {
                default: withCtx(() => [
                  createVNode("div", { class: "w-full bg-white dark:bg-gray-700 px-4 py-4 space-y-4" }, [
                    createVNode("p", { class: "text-brand-800 dark:text-brand-50 text-xl font-bold w-full" }, "Get Contact Info for Selected Contacts"),
                    createVNode("p", { class: "text-sm text-brand-950 dark:text-brand-50" }, [
                      createTextVNode("You have selected "),
                      createVNode("span", { class: "font-bold" }, toDisplayString(selectForm.value.items.length) + " contacts", 1),
                      createTextVNode(" for lookup. "),
                      createVNode("span", { class: "font-bold" }, "9 contacts"),
                      createTextVNode(" haven't been previously looked up so this will use up to 9 credits. Continue?")
                    ]),
                    createVNode("div", { class: "w-full flex justify-end items-center gap-3" }, [
                      createVNode("button", { class: "font-normal px-5 py-1.5 rounded-md bg-brand-500 hover:bg-brand-600 border border-brand-500 hover:border-brand-600 text-white" }, "Ok"),
                      createVNode("button", {
                        onClick: withModifiers(toggleShowGetContact, ["prevent"]),
                        class: "dark:text-gray-200 text-gray-600 font-medium px-5 py-1.5 rounded-md bg-white dark:bg-white/[0.2] hover:bg-gray-100 border border-gray-400 dark:border-gray-700 hover:border-gray-600"
                      }, "Cancel")
                    ])
                  ])
                ]),
                _: 1
              }, 8, ["show"]),
              createVNode(_sfc_main$8, {
                show: openPricingModal.value,
                onClose: toggleOpenPricingModal,
                closeable: true,
                "max-width": `${unref(props).plans.length > 1 ? "1/2" : "lg"}`
              }, {
                default: withCtx(() => [
                  createVNode(_sfc_main$1, {
                    plans: _ctx.$page.props.plans,
                    "filtered-data": _ctx.$page.props.items.total
                  }, null, 8, ["plans", "filtered-data"])
                ]),
                _: 1
              }, 8, ["show", "max-width"])
            ];
          }
        }),
        _: 1
      }, _parent));
      _push(`<!--]-->`);
    };
  }
};
const _sfc_setup = _sfc_main.setup;
_sfc_main.setup = (props, ctx) => {
  const ssrContext = useSSRContext();
  (ssrContext.modules || (ssrContext.modules = /* @__PURE__ */ new Set())).add("resources/js/Pages/Base/Discover/Search.vue");
  return _sfc_setup ? _sfc_setup(props, ctx) : void 0;
};
const Search = /* @__PURE__ */ _export_sfc(_sfc_main, [["__scopeId", "data-v-b3c24c67"]]);
export {
  Search as default
};
