<?php

namespace Database\Factories;

use Exception;
use Carbon\Carbon;
use Illuminate\Support\Str;
use App\Models\Subscription;
use App\Enums\StripeStatusType;
use App\Enums\SubscriptionStatus;
use App\Enums\SubscriptionMigrationType;
use Illuminate\Database\Eloquent\Factories\Factory;

/**
 * @extends Factory<Subscription>
 */
class SubscriptionFactory extends Factory
{
    /**
     * Define the model's default state.
     *
     * @return array<string, mixed>
     * @throws Exception
     */
    public function definition(): array
    {
        $start = fake()->dateTimeBetween('-1 year', 'now');
        $end = Carbon::parse($start)->addDays(30);

        return [
            'user_id'                  => \App\Models\User::inRandomOrder()->first(),
            'plan_id'                  => \App\Models\Plan::inRandomOrder()->first(),
            'current_period_starts_at' => $start,
            'current_period_ends_at'   => $end,
            'prorated_amount'          => fake()->randomFloat(2, 0, 500),
            'credit_balance'           => fake()->randomFloat(2, 0, 1000),
            'currency'                 => 'USD',
            'migration_status'         => $this->faker->randomElement(array_column(SubscriptionStatus::cases(), "value")),
            'migration_type'           => $this->faker->randomElement(array_column(SubscriptionMigrationType::cases(), "value")),
            'grandfather_pricing'      => fake()->boolean(20),
            'migration_initiator_ip'   => $this->faker->ipv4(),
            'type'                     => "sepa_debit",
            'stripe_id'                => Str::uuid()->serialize(),
            'stripe_status'            => $this->faker->randomElement(array_column(StripeStatusType::cases(), 'value')),
            'stripe_price'             => $this->faker->randomNumber(),
            'quantity'                 => $this->faker->randomNumber(),
            'trial_ends_at'            => now()->addDays(rand(10, 15)),
        ];
    }

    /**
     * @return $this
     */
    public function expired(): static
    {
        return $this->state(fn(array $attributes) => [
            'current_period_ends_at' => now()->subDays(7),
        ]);
    }

    public function randomStatus(): static
    {
        return $this->state(fn(array $attributes) => [
            'migration_status' => $this->faker->randomElement(array_column(SubscriptionStatus::cases(), "value")),
        ]);
    }

    public function failedMigration(): static
    {
        return $this->state(fn(array $attributes) => [
            'migration_status' => 'failed',
        ]);
    }
}
