<?php

use App\Enums\StripeStatusType;
use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration {
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('subscriptions', function (Blueprint $table) {
            // Core Identification
            $table->id();
            $table->foreignIdFor(\App\Models\User::class)->constrained()->cascadeOnDelete();
            $table->foreignIdFor(\App\Models\Plan::class)->constrained()->cascadeOnDelete();
            // Migration Tracking
            $table->uuid('previous_subscription_id')->nullable();
            $table->uuid('migrated_from_plan_id')->nullable();
            $table->uuid('migrated_to_plan_id')->nullable();
            $table->uuid('remaining_records')->nullable();

            // Temporal Tracking
            $table->timestamp('current_period_starts_at');
            $table->timestamp('current_period_ends_at')->nullable();
            $table->timestamp('migration_effective_date')->nullable();
            // Financial Columns
            $table->decimal('prorated_amount', 10, 2)->default(0);
            $table->decimal('credit_balance', 10, 2)->default(0);
            $table->string('currency', 3)->default('USD');

            // State Management
            $table->enum('migration_status', array_column(\App\Enums\SubscriptionStatus::cases(), 'value'))->default(\App\Enums\SubscriptionStatus::PENDING->value);

            $table->enum('migration_type', array_column(\App\Enums\SubscriptionMigrationType::cases(), "value"))->nullable();

            // Cancellation Protection
            $table->boolean('grandfather_pricing')->default(false);
            $table->text('cancellation_reason')->nullable();

            // Audit Trail
            $table->timestamp('migration_initiated_at')->nullable();
            $table->timestamp('migration_completed_at')->nullable();
            $table->ipAddress('migration_initiator_ip')->nullable();
            $table->timestamps();
            $table->softDeletes();

            // stripe
            $table->string('type');
            $table->string('stripe_id')->unique();
            $table->enum('stripe_status', array_column(StripeStatusType::cases(), 'value'))->default(StripeStatusType::PAYMENT_INTENT->value);
            $table->string('stripe_price')->nullable();
            $table->integer('quantity')->nullable();
            $table->timestamp('trial_ends_at')->nullable();
            // Indexes
            $table->index(['migration_status', 'migration_effective_date']);
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('subscriptions');
    }
};
