<?php

namespace Database\Seeders;

use App\Enums\PlanProductType;
use App\Models\DataFactory;
use App\Models\Plan;
use App\Models\User;

// use Illuminate\Database\Console\Seeds\WithoutModelEvents;
use Illuminate\Database\Seeder;

class DatabaseSeeder extends Seeder
{
    /**
     * Seed the application's database.
     */
    public function run(): void
    {

        Plan::factory()->createMany([
            [
                'name'               => 'Essentials',
                'price'              => 0.50,
                'billing_cycle_days' => 30,
                'product_line'       => PlanProductType::EMAIL_ONLY->value,
                'record_limit'       => 5000
            ],
            [
                'name'               => 'Pro',
                'price'              => 0.45,
                'billing_cycle_days' => 30,
                'is_recommended'     => true,
                'product_line'       => PlanProductType::EMAIL_AND_PHONE->value,
                'record_limit'       => 10000
            ],
            [
                'name'               => 'Ultimate',
                'price'              => 0.40,
                'billing_cycle_days' => 365,
                'product_line'       => PlanProductType::EMAIL_AND_PHONE->value,
                'record_limit'       => 15000
            ]
        ]);

        // Generate test users
        /*User::factory()->count(50)->has(\Admin\Models\Subscription::factory()->count(2)->state(function (array $attributes, User $user) {
            return ['user_id' => $user->id];
        }))->create();*/
        User::factory()->count(50)->hasSubscriptions([
            'plan_id' => \App\Models\Plan::inRandomOrder()->first(),
        ])->create();

        // Create admin user
        User::factory()->hasSubscriptions([
            'plan_id' => \App\Models\Plan::where('name', 'Pro')->first()
        ])->create([
            'name'     => 'Hm Shahed',
            'email'    => 'admin@admin.com',
            'password' => bcrypt('password'),
            'is_admin' => true,
        ]);

        // Create expired subscription
        //$expired = \Admin\Models\Subscription::factory()->expired()->create();

        // Create failed migration scenario
        $failed = \App\Models\Subscription::factory()->failedMigration()->create();
        //DataFactory::factory()->count(5000)->create();
    }
}
